import * as ng_primitives_state from 'ng-primitives/state';
import * as _angular_core from '@angular/core';
import { InjectionToken, Provider } from '@angular/core';
import * as flowbite_angular_alert from 'flowbite-angular/alert';
import { FlowbiteColors, ColorToTheme, FlowbiteBoolean, DeepPartial } from 'flowbite-angular';
import * as i1 from 'ng-primitives/button';
import * as i2 from 'ng-primitives/interactions';

interface FlowbiteAlertColors extends Pick<FlowbiteColors, 'default' | 'info' | 'failure' | 'success' | 'warning' | 'primary'> {
    [key: string]: ColorToTheme;
}
interface FlowbiteAlertTheme {
    host: FlowbiteAlertHostTheme;
}
interface FlowbiteAlertHostTheme {
    base: string;
    transition: string;
    color: FlowbiteAlertColors;
    border: FlowbiteBoolean;
    accent: FlowbiteBoolean;
}
declare const flowbiteAlertTheme: FlowbiteAlertTheme;

interface FlowbiteAlertConfig {
    /**
     * The default theme of alert
     */
    baseTheme: FlowbiteAlertTheme;
    /**
     * The default color of alert
     */
    color: keyof FlowbiteAlertColors;
    /**
     * Wether the alert has border
     */
    border: boolean;
    /**
     * Wether the alert has border accent
     */
    accent: boolean;
    /**
     * The custom theme of alert
     */
    customTheme: DeepPartial<FlowbiteAlertTheme>;
}
declare const defaultFlowbiteAlertConfig: FlowbiteAlertConfig;
declare const FlowbiteAlertConfigToken: InjectionToken<FlowbiteAlertConfig>;
/**
 * Provide the default Alert configuration
 * @param config The Alert configuration
 * @returns The provider
 */
declare const provideFlowbiteAlertConfig: (config: Partial<FlowbiteAlertConfig>) => Provider[];
/**
 * Inject the Alert configuration
 * @see {@link defaultFlowbiteAlertConfig}
 * @returns The configuration
 */
declare const injectFlowbiteAlertConfig: () => FlowbiteAlertConfig;

declare class Alert {
    readonly config: FlowbiteAlertConfig;
    /**
     * @see {@link injectFlowbiteAlertConfig}
     */
    readonly color: _angular_core.InputSignal<keyof flowbite_angular_alert.FlowbiteAlertColors>;
    /**
     * @see {@link injectFlowbiteAlertConfig}
     */
    readonly border: _angular_core.InputSignalWithTransform<boolean, unknown>;
    /**
     * @see {@link injectFlowbiteAlertConfig}
     */
    readonly accent: _angular_core.InputSignalWithTransform<boolean, unknown>;
    /**
     * @see {@link injectFlowbiteAlertConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
            border?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
            accent?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<Alert>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<Alert, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<Alert, "    div[flowbiteAlert]  ", ["flowbiteAlert"], { "color": { "alias": "color"; "required": false; "isSignal": true; }; "border": { "alias": "border"; "required": false; "isSignal": true; }; "accent": { "alias": "accent"; "required": false; "isSignal": true; }; "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, never>;
}

declare const FlowbiteAlertStateToken: _angular_core.InjectionToken<Alert>;
declare const provideFlowbiteAlertState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteAlertState: <U = {
    readonly config: flowbite_angular_alert.FlowbiteAlertConfig;
    readonly color: _angular_core.InputSignal<keyof flowbite_angular_alert.FlowbiteAlertColors>;
    readonly border: _angular_core.InputSignalWithTransform<boolean, unknown>;
    readonly accent: _angular_core.InputSignalWithTransform<boolean, unknown>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
            border?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
            accent?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<Alert>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteAlertState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

interface FlowbiteAlertButtonTheme {
    host: FlowbiteAlertButtonHostTheme;
}
interface FlowbiteAlertButtonHostTheme {
    base: string;
    transition: string;
    color: FlowbiteAlertColors;
}
declare const flowbiteAlertButtonTheme: FlowbiteAlertButtonTheme;

interface FlowbiteAlertButtonConfig {
    /**
     * The default theme of AlertButton
     */
    baseTheme: FlowbiteAlertButtonTheme;
    /**
     * The custom theme of AlertButton
     */
    customTheme: DeepPartial<FlowbiteAlertButtonTheme>;
}
declare const defaultFlowbiteAlertButtonConfig: FlowbiteAlertButtonConfig;
declare const FlowbiteAlertButtonConfigToken: InjectionToken<FlowbiteAlertButtonConfig>;
/**
 * Provide the default AlertButton configuration
 * @param config The AlertButton configuration
 * @returns The provider
 */
declare const provideFlowbiteAlertButtonConfig: (config: Partial<FlowbiteAlertButtonConfig>) => Provider[];
/**
 * Inject the AlertButton configuration
 * @see {@link defaultFlowbiteAlertButtonConfig}
 * @returns The configuration
 */
declare const injectFlowbiteAlertButtonConfig: () => FlowbiteAlertButtonConfig;

declare class AlertButton {
    readonly config: FlowbiteAlertButtonConfig;
    readonly alertState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: flowbite_angular_alert.FlowbiteAlertConfig;
        readonly color: _angular_core.InputSignal<keyof flowbite_angular_alert.FlowbiteAlertColors>;
        readonly border: _angular_core.InputSignalWithTransform<boolean, unknown>;
        readonly accent: _angular_core.InputSignalWithTransform<boolean, unknown>;
        readonly customTheme: _angular_core.InputSignal<{
            host?: {
                base?: string | undefined;
                transition?: string | undefined;
                color?: {
                    [x: string]: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    default?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    info?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    failure?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    success?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    warning?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    primary?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                } | undefined;
                border?: {
                    off?: string | undefined;
                    on?: string | undefined;
                } | undefined;
                accent?: {
                    off?: string | undefined;
                    on?: string | undefined;
                } | undefined;
            } | undefined;
        }>;
        readonly theme: _angular_core.Signal<{
            host: {
                root: string;
            };
        }>;
        readonly state: ng_primitives_state.CreatedState<flowbite_angular_alert.Alert>;
    }>>;
    /**
     * @see {@link injectFlowbiteAlertButtonConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<AlertButton>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<AlertButton, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<AlertButton, "    button[flowbiteAlertButton],    a[flowbiteAlertButton]  ", ["flowbiteAlertButton"], { "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, [{ directive: typeof i1.NgpButton; inputs: { "disabled": "disabled"; }; outputs: {}; }, { directive: typeof i2.NgpFocus; inputs: {}; outputs: {}; }]>;
}

declare const FlowbiteAlertButtonStateToken: _angular_core.InjectionToken<AlertButton>;
declare const provideFlowbiteAlertButtonState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteAlertButtonState: <U = {
    readonly config: flowbite_angular_alert.FlowbiteAlertButtonConfig;
    readonly alertState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: /*elided*/ any;
        readonly color: /*elided*/ any;
        readonly border: /*elided*/ any;
        readonly accent: /*elided*/ any;
        readonly customTheme: /*elided*/ any;
        readonly theme: /*elided*/ any;
        readonly state: /*elided*/ any;
    }>>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<AlertButton>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteAlertButtonState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

interface FlowbiteAlertContentTheme {
    host: FlowbiteAlertContentHostTheme;
}
interface FlowbiteAlertContentHostTheme {
    base: string;
    transition: string;
    color: FlowbiteAlertColors;
}
declare const flowbiteAlertContentTheme: FlowbiteAlertContentTheme;

interface FlowbiteAlertContentConfig {
    /**
     * The default theme of AlertContent
     */
    baseTheme: FlowbiteAlertContentTheme;
    /**
     * The custom theme of AlertContent
     */
    customTheme: DeepPartial<FlowbiteAlertContentTheme>;
}
declare const defaultFlowbiteAlertContentConfig: FlowbiteAlertContentConfig;
declare const FlowbiteAlertContentConfigToken: InjectionToken<FlowbiteAlertContentConfig>;
/**
 * Provide the default AlertContent configuration
 * @param config The AlertContent configuration
 * @returns The provider
 */
declare const provideFlowbiteAlertContentConfig: (config: Partial<FlowbiteAlertContentConfig>) => Provider[];
/**
 * Inject the AlertContent configuration
 * @see {@link defaultFlowbiteAlertContentConfig}
 * @returns The configuration
 */
declare const injectFlowbiteAlertContentConfig: () => FlowbiteAlertContentConfig;

declare class AlertContent {
    readonly config: FlowbiteAlertContentConfig;
    readonly alertState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: flowbite_angular_alert.FlowbiteAlertConfig;
        readonly color: _angular_core.InputSignal<keyof flowbite_angular_alert.FlowbiteAlertColors>;
        readonly border: _angular_core.InputSignalWithTransform<boolean, unknown>;
        readonly accent: _angular_core.InputSignalWithTransform<boolean, unknown>;
        readonly customTheme: _angular_core.InputSignal<{
            host?: {
                base?: string | undefined;
                transition?: string | undefined;
                color?: {
                    [x: string]: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    default?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    info?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    failure?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    success?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    warning?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    primary?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                } | undefined;
                border?: {
                    off?: string | undefined;
                    on?: string | undefined;
                } | undefined;
                accent?: {
                    off?: string | undefined;
                    on?: string | undefined;
                } | undefined;
            } | undefined;
        }>;
        readonly theme: _angular_core.Signal<{
            host: {
                root: string;
            };
        }>;
        readonly state: ng_primitives_state.CreatedState<flowbite_angular_alert.Alert>;
    }>>;
    /**
     * @see {@link injectFlowbiteAlertContentConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<AlertContent>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<AlertContent, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<AlertContent, "    div[flowbiteAlertContent]  ", ["flowbiteAlertContent"], { "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, never>;
}

declare const FlowbiteAlertContentStateToken: _angular_core.InjectionToken<AlertContent>;
declare const provideFlowbiteAlertContentState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteAlertContentState: <U = {
    readonly config: flowbite_angular_alert.FlowbiteAlertContentConfig;
    readonly alertState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: /*elided*/ any;
        readonly color: /*elided*/ any;
        readonly border: /*elided*/ any;
        readonly accent: /*elided*/ any;
        readonly customTheme: /*elided*/ any;
        readonly theme: /*elided*/ any;
        readonly state: /*elided*/ any;
    }>>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<AlertContent>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteAlertContentState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

export { Alert, AlertButton, AlertContent, FlowbiteAlertButtonConfigToken, FlowbiteAlertButtonStateToken, FlowbiteAlertConfigToken, FlowbiteAlertContentConfigToken, FlowbiteAlertContentStateToken, FlowbiteAlertStateToken, defaultFlowbiteAlertButtonConfig, defaultFlowbiteAlertConfig, defaultFlowbiteAlertContentConfig, flowbiteAlertButtonState, flowbiteAlertButtonTheme, flowbiteAlertContentState, flowbiteAlertContentTheme, flowbiteAlertState, flowbiteAlertTheme, injectFlowbiteAlertButtonConfig, injectFlowbiteAlertButtonState, injectFlowbiteAlertConfig, injectFlowbiteAlertContentConfig, injectFlowbiteAlertContentState, injectFlowbiteAlertState, provideFlowbiteAlertButtonConfig, provideFlowbiteAlertButtonState, provideFlowbiteAlertConfig, provideFlowbiteAlertContentConfig, provideFlowbiteAlertContentState, provideFlowbiteAlertState };
export type { FlowbiteAlertButtonConfig, FlowbiteAlertButtonHostTheme, FlowbiteAlertButtonTheme, FlowbiteAlertColors, FlowbiteAlertConfig, FlowbiteAlertContentConfig, FlowbiteAlertContentHostTheme, FlowbiteAlertContentTheme, FlowbiteAlertHostTheme, FlowbiteAlertTheme };
