import * as ng_primitives_state from 'ng-primitives/state';
import * as _angular_core from '@angular/core';
import { InjectionToken, Provider } from '@angular/core';
import * as flowbite_angular_badge from 'flowbite-angular/badge';
import { FlowbiteColors, ColorToTheme, FlowbiteBoolean, FlowbiteSizes, DeepPartial } from 'flowbite-angular';
import * as i2 from 'ng-primitives/button';
import * as i3 from 'ng-primitives/interactions';

interface FlowbiteBadgeColors extends Pick<FlowbiteColors, 'default' | 'info' | 'failure' | 'success' | 'warning' | 'primary'> {
    [key: string]: ColorToTheme;
}
interface FlowbiteBadgeSizes extends Pick<FlowbiteSizes, 'xs' | 'sm'> {
    [key: string]: string;
}
interface FlowbiteBadgeTheme {
    host: FlowbiteBadgeHostTheme;
}
interface FlowbiteBadgeHostTheme {
    base: string;
    transition: string;
    color: FlowbiteBadgeColors;
    border: FlowbiteBoolean;
    size: FlowbiteBadgeSizes;
    pill: FlowbiteBoolean;
}
declare const flowbiteBadgeTheme: FlowbiteBadgeTheme;

interface FlowbiteBadgeConfig {
    /**
     * The default theme of badge
     */
    baseTheme: FlowbiteBadgeTheme;
    /**
     * The default color of badge
     */
    color: keyof FlowbiteBadgeColors;
    /**
     * Wether the badge has border
     */
    border: boolean;
    /**
     * Wether the badge is pill
     */
    pill: boolean;
    /**
     * The default size of badge
     */
    size: keyof FlowbiteBadgeSizes;
    /**
     * The custom theme of badge
     */
    customTheme: DeepPartial<FlowbiteBadgeTheme>;
}
declare const defaultFlowbiteBadgeConfig: FlowbiteBadgeConfig;
declare const FlowbiteBadgeConfigToken: InjectionToken<FlowbiteBadgeConfig>;
/**
 * Provide the default Badge configuration
 * @param config The Badge configuration
 * @returns The provider
 */
declare const provideFlowbiteBadgeConfig: (config: Partial<FlowbiteBadgeConfig>) => Provider[];
/**
 * Inject the Badge configuration
 * @see {@link defaultFlowbiteBadgeConfig}
 * @returns The configuration
 */
declare const injectFlowbiteBadgeConfig: () => FlowbiteBadgeConfig;

declare class Badge {
    readonly config: FlowbiteBadgeConfig;
    /**
     * @see {@link injectFlowbiteBadgeConfig}
     */
    readonly color: _angular_core.InputSignal<keyof flowbite_angular_badge.FlowbiteBadgeColors>;
    /**
     * @see {@link injectFlowbiteBadgeConfig}
     */
    readonly border: _angular_core.InputSignalWithTransform<boolean, unknown>;
    /**
     * @see {@link injectFlowbiteBadgeConfig}
     */
    readonly pill: _angular_core.InputSignalWithTransform<boolean, unknown>;
    /**
     * @see {@link injectFlowbiteBadgeConfig}
     */
    readonly size: _angular_core.InputSignal<keyof flowbite_angular_badge.FlowbiteBadgeSizes>;
    /**
     * @see {@link injectFlowbiteBadgeConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
            border?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
            } | undefined;
            pill?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<Badge>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<Badge, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<Badge, "    span[flowbiteBadge]  ", ["flowbiteBadge"], { "color": { "alias": "color"; "required": false; "isSignal": true; }; "border": { "alias": "border"; "required": false; "isSignal": true; }; "pill": { "alias": "pill"; "required": false; "isSignal": true; }; "size": { "alias": "size"; "required": false; "isSignal": true; }; "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, never>;
}

declare const FlowbiteBadgeStateToken: _angular_core.InjectionToken<Badge>;
declare const provideFlowbiteBadgeState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteBadgeState: <U = {
    readonly config: flowbite_angular_badge.FlowbiteBadgeConfig;
    readonly color: _angular_core.InputSignal<keyof flowbite_angular_badge.FlowbiteBadgeColors>;
    readonly border: _angular_core.InputSignalWithTransform<boolean, unknown>;
    readonly pill: _angular_core.InputSignalWithTransform<boolean, unknown>;
    readonly size: _angular_core.InputSignal<keyof flowbite_angular_badge.FlowbiteBadgeSizes>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
            border?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
            } | undefined;
            pill?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<Badge>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteBadgeState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

interface FlowbiteBadgeLinkTheme {
    host: FlowbiteBadgeLinkHostTheme;
}
interface FlowbiteBadgeLinkHostTheme {
    base: string;
    transition: string;
    color: FlowbiteBadgeColors;
}
declare const flowbiteBadgeLinkTheme: FlowbiteBadgeLinkTheme;

interface FlowbiteBadgeLinkConfig {
    /**
     * The default theme of BadgeLink
     */
    baseTheme: FlowbiteBadgeLinkTheme;
    /**
     * The custom theme of BadgeLink
     */
    customTheme: DeepPartial<FlowbiteBadgeLinkTheme>;
}
declare const defaultFlowbiteBadgeLinkConfig: FlowbiteBadgeLinkConfig;
declare const FlowbiteBadgeLinkConfigToken: InjectionToken<FlowbiteBadgeLinkConfig>;
/**
 * Provide the default BadgeLink configuration
 * @param config The BadgeLink configuration
 * @returns The provider
 */
declare const provideFlowbiteBadgeLinkConfig: (config: Partial<FlowbiteBadgeLinkConfig>) => Provider[];
/**
 * Inject the BadgeLink configuration
 * @see {@link defaultFlowbiteBadgeLinkConfig}
 * @returns The configuration
 */
declare const injectFlowbiteBadgeLinkConfig: () => FlowbiteBadgeLinkConfig;

declare class BadgeLink {
    readonly config: FlowbiteBadgeLinkConfig;
    readonly badgeState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: flowbite_angular_badge.FlowbiteBadgeConfig;
        readonly color: _angular_core.InputSignal<keyof flowbite_angular_badge.FlowbiteBadgeColors>;
        readonly border: _angular_core.InputSignalWithTransform<boolean, unknown>;
        readonly pill: _angular_core.InputSignalWithTransform<boolean, unknown>;
        readonly size: _angular_core.InputSignal<keyof flowbite_angular_badge.FlowbiteBadgeSizes>;
        readonly customTheme: _angular_core.InputSignal<{
            host?: {
                base?: string | undefined;
                transition?: string | undefined;
                color?: {
                    [x: string]: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    default?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    info?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    failure?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    success?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    warning?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    primary?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                } | undefined;
                border?: {
                    off?: string | undefined;
                    on?: string | undefined;
                } | undefined;
                size?: {
                    [x: string]: string | undefined;
                    xs?: string | undefined;
                    sm?: string | undefined;
                } | undefined;
                pill?: {
                    off?: string | undefined;
                    on?: string | undefined;
                } | undefined;
            } | undefined;
        }>;
        readonly theme: _angular_core.Signal<{
            host: {
                root: string;
            };
        }>;
        readonly state: ng_primitives_state.CreatedState<Badge>;
    }>>;
    /**
     * @see {@link injectFlowbiteBadgeLinkConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<BadgeLink>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<BadgeLink, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<BadgeLink, "    button[flowbiteBadgeLink],    a[flowbiteBadgeLink]  ", ["flowbiteBadgeLink"], { "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, [{ directive: typeof Badge; inputs: { "color": "color"; "border": "border"; "pill": "pill"; "size": "size"; "customTheme": "badgeCustomTheme"; }; outputs: {}; }, { directive: typeof i2.NgpButton; inputs: { "disabled": "disabled"; }; outputs: {}; }, { directive: typeof i3.NgpFocus; inputs: {}; outputs: {}; }]>;
}

declare const FlowbiteBadgeLinkStateToken: _angular_core.InjectionToken<BadgeLink>;
declare const provideFlowbiteBadgeLinkState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteBadgeLinkState: <U = {
    readonly config: flowbite_angular_badge.FlowbiteBadgeLinkConfig;
    readonly badgeState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: /*elided*/ any;
        readonly color: /*elided*/ any;
        readonly border: /*elided*/ any;
        readonly pill: /*elided*/ any;
        readonly size: /*elided*/ any;
        readonly customTheme: /*elided*/ any;
        readonly theme: /*elided*/ any;
        readonly state: /*elided*/ any;
    }>>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<BadgeLink>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteBadgeLinkState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

interface FlowbiteBadgeButtonTheme {
    host: FlowbiteBadgeButtonHostTheme;
}
interface FlowbiteBadgeButtonHostTheme {
    base: string;
    color: FlowbiteBadgeColors;
}
declare const flowbiteBadgeButtonTheme: FlowbiteBadgeButtonTheme;

interface FlowbiteBadgeButtonConfig {
    /**
     * The default theme of BadgeButton
     */
    baseTheme: FlowbiteBadgeButtonTheme;
    /**
     * The custom theme of BadgeButton
     */
    customTheme: DeepPartial<FlowbiteBadgeButtonTheme>;
}
declare const defaultFlowbiteBadgeButtonConfig: FlowbiteBadgeButtonConfig;
declare const FlowbiteBadgeButtonConfigToken: InjectionToken<FlowbiteBadgeButtonConfig>;
/**
 * Provide the default BadgeButton configuration
 * @param config The BadgeButton configuration
 * @returns The provider
 */
declare const provideFlowbiteBadgeButtonConfig: (config: Partial<FlowbiteBadgeButtonConfig>) => Provider[];
/**
 * Inject the BadgeButton configuration
 * @see {@link defaultFlowbiteBadgeButtonConfig}
 * @returns The configuration
 */
declare const injectFlowbiteBadgeButtonConfig: () => FlowbiteBadgeButtonConfig;

declare class BadgeButton {
    readonly config: FlowbiteBadgeButtonConfig;
    readonly badgeState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: flowbite_angular_badge.FlowbiteBadgeConfig;
        readonly color: _angular_core.InputSignal<keyof flowbite_angular_badge.FlowbiteBadgeColors>;
        readonly border: _angular_core.InputSignalWithTransform<boolean, unknown>;
        readonly pill: _angular_core.InputSignalWithTransform<boolean, unknown>;
        readonly size: _angular_core.InputSignal<keyof flowbite_angular_badge.FlowbiteBadgeSizes>;
        readonly customTheme: _angular_core.InputSignal<{
            host?: {
                base?: string | undefined;
                transition?: string | undefined;
                color?: {
                    [x: string]: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    default?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    info?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    failure?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    success?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    warning?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    primary?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                } | undefined;
                border?: {
                    off?: string | undefined;
                    on?: string | undefined;
                } | undefined;
                size?: {
                    [x: string]: string | undefined;
                    xs?: string | undefined;
                    sm?: string | undefined;
                } | undefined;
                pill?: {
                    off?: string | undefined;
                    on?: string | undefined;
                } | undefined;
            } | undefined;
        }>;
        readonly theme: _angular_core.Signal<{
            host: {
                root: string;
            };
        }>;
        readonly state: ng_primitives_state.CreatedState<flowbite_angular_badge.Badge>;
    }>>;
    /**
     * @see {@link injectFlowbiteBadgeButtonConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<BadgeButton>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<BadgeButton, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<BadgeButton, "    button[flowbiteBadgeButton],    a[flowbiteBadgeButton]  ", ["flowbiteBadgeButton"], { "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, [{ directive: typeof i2.NgpButton; inputs: { "disabled": "disabled"; }; outputs: {}; }, { directive: typeof i3.NgpFocus; inputs: {}; outputs: {}; }]>;
}

declare const FlowbiteBadgeButtonStateToken: _angular_core.InjectionToken<BadgeButton>;
declare const provideFlowbiteBadgeButtonState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteBadgeButtonState: <U = {
    readonly config: flowbite_angular_badge.FlowbiteBadgeButtonConfig;
    readonly badgeState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: /*elided*/ any;
        readonly color: /*elided*/ any;
        readonly border: /*elided*/ any;
        readonly pill: /*elided*/ any;
        readonly size: /*elided*/ any;
        readonly customTheme: /*elided*/ any;
        readonly theme: /*elided*/ any;
        readonly state: /*elided*/ any;
    }>>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<BadgeButton>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteBadgeButtonState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

export { Badge, BadgeButton, BadgeLink, FlowbiteBadgeButtonConfigToken, FlowbiteBadgeButtonStateToken, FlowbiteBadgeConfigToken, FlowbiteBadgeLinkConfigToken, FlowbiteBadgeLinkStateToken, FlowbiteBadgeStateToken, defaultFlowbiteBadgeButtonConfig, defaultFlowbiteBadgeConfig, defaultFlowbiteBadgeLinkConfig, flowbiteBadgeButtonState, flowbiteBadgeButtonTheme, flowbiteBadgeLinkState, flowbiteBadgeLinkTheme, flowbiteBadgeState, flowbiteBadgeTheme, injectFlowbiteBadgeButtonConfig, injectFlowbiteBadgeButtonState, injectFlowbiteBadgeConfig, injectFlowbiteBadgeLinkConfig, injectFlowbiteBadgeLinkState, injectFlowbiteBadgeState, provideFlowbiteBadgeButtonConfig, provideFlowbiteBadgeButtonState, provideFlowbiteBadgeConfig, provideFlowbiteBadgeLinkConfig, provideFlowbiteBadgeLinkState, provideFlowbiteBadgeState };
export type { FlowbiteBadgeButtonConfig, FlowbiteBadgeButtonHostTheme, FlowbiteBadgeButtonTheme, FlowbiteBadgeColors, FlowbiteBadgeConfig, FlowbiteBadgeHostTheme, FlowbiteBadgeLinkConfig, FlowbiteBadgeLinkHostTheme, FlowbiteBadgeLinkTheme, FlowbiteBadgeSizes, FlowbiteBadgeTheme };
