import * as ng_primitives_state from 'ng-primitives/state';
import * as _angular_core from '@angular/core';
import { InjectionToken, Provider } from '@angular/core';
import * as flowbite_angular_breadcrumb from 'flowbite-angular/breadcrumb';
import { FlowbiteBoolean, FlowbiteColors, ColorToTheme, DeepPartial } from 'flowbite-angular';
import * as i1 from 'ng-primitives/button';
import * as i2 from 'ng-primitives/interactions';

interface FlowbiteBreadcrumbColors extends Pick<FlowbiteColors, 'default' | 'info' | 'failure' | 'success' | 'warning' | 'primary'> {
    [ket: string]: ColorToTheme;
}
interface FlowbiteBreadcrumbTheme {
    host: FlowbiteBreadcrumbHostTheme;
}
interface FlowbiteBreadcrumbHostTheme {
    base: string;
    transition: string;
    solid: FlowbiteBoolean;
    color: FlowbiteBreadcrumbColors;
}
declare const flowbiteBreadcrumbTheme: FlowbiteBreadcrumbTheme;

interface FlowbiteBreadcrumbConfig {
    /**
     * The default theme of breadcrumb
     */
    baseTheme: FlowbiteBreadcrumbTheme;
    /**
     * The default color of breadcrumb
     */
    color: keyof FlowbiteBreadcrumbColors;
    /**
     * Whether the breadcrumb is solid
     */
    solid: boolean;
    /**
     * The custom theme of breadcrumb
     */
    customTheme: DeepPartial<FlowbiteBreadcrumbTheme>;
}
declare const defaultFlowbiteBreadcrumbConfig: FlowbiteBreadcrumbConfig;
declare const FlowbiteBreadcrumbConfigToken: InjectionToken<FlowbiteBreadcrumbConfig>;
/**
 * Provide the default Breadcrumb configuration
 * @param config The Breadcrumb configuration
 * @returns The provider
 */
declare const provideFlowbiteBreadcrumbConfig: (config: Partial<FlowbiteBreadcrumbConfig>) => Provider[];
/**
 * Inject the Breadcrumb configuration
 * @see {@link defaultFlowbiteBreadcrumbConfig}
 * @returns The configuration
 */
declare const injectFlowbiteBreadcrumbConfig: () => FlowbiteBreadcrumbConfig;

declare class Breadcrumb {
    readonly config: FlowbiteBreadcrumbConfig;
    /**
     * @see {@link injectFlowbiteBreadcrumbConfig}
     */
    readonly color: _angular_core.InputSignal<keyof flowbite_angular_breadcrumb.FlowbiteBreadcrumbColors>;
    /**
     * @see {@link injectFlowbiteBreadcrumbConfig}
     */
    readonly solid: _angular_core.InputSignalWithTransform<boolean, unknown>;
    /**
     * @see {@link injectFlowbiteBreadcrumbConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            solid?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<Breadcrumb>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<Breadcrumb, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<Breadcrumb, "    nav[flowbiteBreadcrumb]  ", ["flowbiteBreadcrumb"], { "color": { "alias": "color"; "required": false; "isSignal": true; }; "solid": { "alias": "solid"; "required": false; "isSignal": true; }; "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, never>;
}

declare const FlowbiteBreadcrumbStateToken: _angular_core.InjectionToken<Breadcrumb>;
declare const provideFlowbiteBreadcrumbState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteBreadcrumbState: <U = {
    readonly config: flowbite_angular_breadcrumb.FlowbiteBreadcrumbConfig;
    readonly color: _angular_core.InputSignal<keyof flowbite_angular_breadcrumb.FlowbiteBreadcrumbColors>;
    readonly solid: _angular_core.InputSignalWithTransform<boolean, unknown>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            solid?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<Breadcrumb>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteBreadcrumbState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

interface FlowbiteBreadcrumbItemTheme {
    host: FlowbiteBreadcrumbItemHostTheme;
}
interface FlowbiteBreadcrumbItemHostTheme {
    base: string;
    transition: string;
    color: FlowbiteBreadcrumbColors;
}
declare const flowbiteBreadcrumbItemTheme: FlowbiteBreadcrumbItemTheme;

interface FlowbiteBreadcrumbItemConfig {
    /**
     * The default theme of breadcrumb item
     */
    baseTheme: FlowbiteBreadcrumbItemTheme;
    /**
     * The custom theme of breadcrumb item
     */
    customTheme: DeepPartial<FlowbiteBreadcrumbItemTheme>;
}
declare const defaultFlowbiteBreadcrumbItemConfig: FlowbiteBreadcrumbItemConfig;
declare const FlowbiteBreadcrumbItemConfigToken: InjectionToken<FlowbiteBreadcrumbItemConfig>;
/**
 * Provide the default Breadcrumb Item configuration
 * @param config The Breadcrumb configuration
 * @returns The provider
 */
declare const provideFlowbiteBreadcrumbItemConfig: (config: Partial<FlowbiteBreadcrumbItemConfig>) => Provider[];
/**
 * Inject the Breadcrumb Item configuration
 * @see {@link defaultFlowbiteBreadcrumbItemConfig}
 * @returns The configuration
 */
declare const injectFlowbiteBreadcrumbItemConfig: () => FlowbiteBreadcrumbItemConfig;

declare class BreadcrumbItem {
    readonly config: FlowbiteBreadcrumbItemConfig;
    readonly breadcrumbState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: flowbite_angular_breadcrumb.FlowbiteBreadcrumbConfig;
        readonly color: _angular_core.InputSignal<keyof flowbite_angular_breadcrumb.FlowbiteBreadcrumbColors>;
        readonly solid: _angular_core.InputSignalWithTransform<boolean, unknown>;
        readonly customTheme: _angular_core.InputSignal<{
            host?: {
                base?: string | undefined;
                transition?: string | undefined;
                solid?: {
                    off?: string | undefined;
                    on?: string | undefined;
                } | undefined;
                color?: {
                    [x: string]: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    default?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    info?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    failure?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    success?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    warning?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    primary?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                } | undefined;
            } | undefined;
        }>;
        readonly theme: _angular_core.Signal<{
            host: {
                root: string;
            };
        }>;
        readonly state: ng_primitives_state.CreatedState<flowbite_angular_breadcrumb.Breadcrumb>;
    }>>;
    /**
     * @see {@link injectFlowbiteBreadcrumbItemConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<BreadcrumbItem>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<BreadcrumbItem, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<BreadcrumbItem, "    li[flowbiteBreadcrumbItem]  ", ["flowbiteBreadcrumbItem"], { "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, [{ directive: typeof i1.NgpButton; inputs: { "disabled": "disabled"; }; outputs: {}; }, { directive: typeof i2.NgpFocus; inputs: {}; outputs: {}; }]>;
}

declare const FlowbiteBreadcrumbItemStateToken: _angular_core.InjectionToken<BreadcrumbItem>;
declare const provideFlowbiteBreadcrumbItemState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteBreadcrumbItemState: <U = {
    readonly config: flowbite_angular_breadcrumb.FlowbiteBreadcrumbItemConfig;
    readonly breadcrumbState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: /*elided*/ any;
        readonly color: /*elided*/ any;
        readonly solid: /*elided*/ any;
        readonly customTheme: /*elided*/ any;
        readonly theme: /*elided*/ any;
        readonly state: /*elided*/ any;
    }>>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<BreadcrumbItem>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteBreadcrumbItemState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

interface FlowbiteBreadcrumbContentTheme {
    host: FlowbiteBreadcrumbContentHostTheme;
}
interface FlowbiteBreadcrumbContentHostTheme {
    base: string;
    transition: string;
}
declare const flowbiteBreadcrumbContentTheme: FlowbiteBreadcrumbContentTheme;

interface FlowbiteBreadcrumbContentConfig {
    /**
     * The default theme of BreadcrumbContent
     */
    baseTheme: FlowbiteBreadcrumbContentTheme;
    /**
     * The custom theme of BreadcrumbContent
     */
    customTheme: DeepPartial<FlowbiteBreadcrumbContentTheme>;
}
declare const defaultFlowbiteBreadcrumbContentConfig: FlowbiteBreadcrumbContentConfig;
declare const FlowbiteBreadcrumbContentConfigToken: InjectionToken<FlowbiteBreadcrumbContentConfig>;
/**
 * Provide the default BreadcrumbContent configuration
 * @param config The BreadcrumbContent configuration
 * @returns The provider
 */
declare const provideFlowbiteBreadcrumbContentConfig: (config: Partial<FlowbiteBreadcrumbContentConfig>) => Provider[];
/**
 * Inject the BreadcrumbContent configuration
 * @see {@link defaultFlowbiteBreadcrumbContentConfig}
 * @returns The configuration
 */
declare const injectFlowbiteBreadcrumbContentConfig: () => FlowbiteBreadcrumbContentConfig;

declare class BreadcrumbContent {
    readonly config: FlowbiteBreadcrumbContentConfig;
    /**
     * @see {@link injectFlowbiteBreadcrumbContentConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<BreadcrumbContent>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<BreadcrumbContent, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<BreadcrumbContent, "    ol[flowbiteBreadcrumbContent]  ", ["flowbiteBreadcrumbContent"], { "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, never>;
}

declare const FlowbiteBreadcrumbContentStateToken: _angular_core.InjectionToken<BreadcrumbContent>;
declare const provideFlowbiteBreadcrumbContentState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteBreadcrumbContentState: <U = {
    readonly config: flowbite_angular_breadcrumb.FlowbiteBreadcrumbContentConfig;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<BreadcrumbContent>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteBreadcrumbContentState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

export { Breadcrumb, BreadcrumbContent, BreadcrumbItem, FlowbiteBreadcrumbConfigToken, FlowbiteBreadcrumbContentConfigToken, FlowbiteBreadcrumbContentStateToken, FlowbiteBreadcrumbItemConfigToken, FlowbiteBreadcrumbItemStateToken, FlowbiteBreadcrumbStateToken, defaultFlowbiteBreadcrumbConfig, defaultFlowbiteBreadcrumbContentConfig, defaultFlowbiteBreadcrumbItemConfig, flowbiteBreadcrumbContentState, flowbiteBreadcrumbContentTheme, flowbiteBreadcrumbItemState, flowbiteBreadcrumbItemTheme, flowbiteBreadcrumbState, flowbiteBreadcrumbTheme, injectFlowbiteBreadcrumbConfig, injectFlowbiteBreadcrumbContentConfig, injectFlowbiteBreadcrumbContentState, injectFlowbiteBreadcrumbItemConfig, injectFlowbiteBreadcrumbItemState, injectFlowbiteBreadcrumbState, provideFlowbiteBreadcrumbConfig, provideFlowbiteBreadcrumbContentConfig, provideFlowbiteBreadcrumbContentState, provideFlowbiteBreadcrumbItemConfig, provideFlowbiteBreadcrumbItemState, provideFlowbiteBreadcrumbState };
export type { FlowbiteBreadcrumbColors, FlowbiteBreadcrumbConfig, FlowbiteBreadcrumbContentConfig, FlowbiteBreadcrumbContentHostTheme, FlowbiteBreadcrumbContentTheme, FlowbiteBreadcrumbHostTheme, FlowbiteBreadcrumbItemConfig, FlowbiteBreadcrumbItemHostTheme, FlowbiteBreadcrumbItemTheme, FlowbiteBreadcrumbTheme };
