import * as ng_primitives_state from 'ng-primitives/state';
import * as _angular_core from '@angular/core';
import { InjectionToken, Provider } from '@angular/core';
import * as flowbite_angular_button from 'flowbite-angular/button';
import { FlowbiteSizes, FlowbiteColors, ColorToTheme, FlowbiteBoolean, DeepPartial } from 'flowbite-angular';
import * as i1 from 'ng-primitives/button';
import * as i2 from 'ng-primitives/interactions';

interface FlowbiteBaseButtonSizes extends Pick<FlowbiteSizes, 'xs' | 'sm' | 'md' | 'lg' | 'xl'> {
    [key: string]: string;
}
interface FlowbiteBaseButtonColors extends Pick<FlowbiteColors, 'default' | 'info' | 'failure' | 'success' | 'warning' | 'primary'> {
    [key: string]: ColorToTheme;
}

interface FlowbiteButtonTheme {
    host: FlowbiteButtonHostTheme;
}
interface FlowbiteButtonHostTheme {
    base: string;
    transition: string;
    focus: string;
    disabled: string;
    size: FlowbiteBaseButtonSizes;
    pill: FlowbiteBoolean;
    color: FlowbiteBaseButtonColors;
    colorOutline: FlowbiteBaseButtonColors;
}
declare const flowbiteButtonTheme: FlowbiteButtonTheme;

interface FlowbiteButtonConfig {
    /**
     * The default theme of button.
     */
    baseTheme: FlowbiteButtonTheme;
    /**
     * The custom theme of button.
     */
    customTheme: DeepPartial<FlowbiteButtonTheme>;
}
declare const defaultFlowbiteButtonConfig: FlowbiteButtonConfig;
declare const FlowbiteButtonConfigToken: InjectionToken<FlowbiteButtonConfig>;
/**
 * Provide the default Button configuration
 * @param config The Button configuration
 * @returns The provider
 */
declare const provideFlowbiteButtonConfig: (config: Partial<FlowbiteButtonConfig>) => Provider[];
/**
 * Inject the Button configuration
 * @see {@link defaultFlowbiteButtonConfig}
 * @returns The configuration
 */
declare const injectFlowbiteButtonConfig: () => FlowbiteButtonConfig;

interface FlowbiteBaseButtonConfig {
    /**
     * The default color of button.
     */
    color: keyof FlowbiteBaseButtonColors;
    /**
     * The default size of button.
     */
    size: keyof FlowbiteBaseButtonSizes;
    /**
     * Whether the button is pill.
     */
    pill: boolean;
    /**
     * Whether the button is outline.
     */
    outline: boolean;
}
declare const defaultFlowbiteBaseButtonConfig: FlowbiteBaseButtonConfig;
declare const FlowbiteBaseButtonConfigToken: InjectionToken<FlowbiteBaseButtonConfig>;
/**
 * Provide the default BaseButton configuration
 * @param config The BaseButton configuration
 * @returns The provider
 */
declare const provideFlowbiteBaseButtonConfig: (config: Partial<FlowbiteBaseButtonConfig>) => Provider[];
/**
 * Inject the BaseButton configuration
 * @see {@link defaultFlowbiteBaseButtonConfig}
 * @returns The configuration
 */
declare const injectFlowbiteBaseButtonConfig: () => FlowbiteBaseButtonConfig;

declare class BaseButton {
    readonly config: FlowbiteBaseButtonConfig;
    /**
     * @see {@link injectFlowbiteBaseButtonConfig}
     */
    readonly color: _angular_core.InputSignal<keyof FlowbiteBaseButtonColors>;
    /**
     * @see {@link injectFlowbiteBaseButtonConfig}
     */
    readonly size: _angular_core.InputSignal<keyof FlowbiteBaseButtonSizes>;
    /**
     * @see {@link injectFlowbiteBaseButtonConfig}
     */
    readonly pill: _angular_core.InputSignalWithTransform<boolean, unknown>;
    /**
     * @see {@link injectFlowbiteBaseButtonConfig}
     */
    readonly outline: _angular_core.InputSignalWithTransform<boolean, unknown>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<BaseButton>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<BaseButton, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<BaseButton, never, never, { "color": { "alias": "color"; "required": false; "isSignal": true; }; "size": { "alias": "size"; "required": false; "isSignal": true; }; "pill": { "alias": "pill"; "required": false; "isSignal": true; }; "outline": { "alias": "outline"; "required": false; "isSignal": true; }; }, {}, never, never, true, never>;
}

declare class Button {
    readonly config: FlowbiteButtonConfig;
    readonly baseButtonState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: flowbite_angular_button.FlowbiteBaseButtonConfig;
        readonly color: _angular_core.InputSignal<keyof flowbite_angular_button.FlowbiteBaseButtonColors>;
        readonly size: _angular_core.InputSignal<keyof flowbite_angular_button.FlowbiteBaseButtonSizes>;
        readonly pill: _angular_core.InputSignalWithTransform<boolean, unknown>;
        readonly outline: _angular_core.InputSignalWithTransform<boolean, unknown>;
        readonly state: ng_primitives_state.CreatedState<BaseButton>;
    }>>;
    /**
     * @see {@link injectFlowbiteButtonConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            focus?: string | undefined;
            disabled?: string | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
                xl?: string | undefined;
            } | undefined;
            pill?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
            colorOutline?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<Button>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<Button, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<Button, "    button[flowbiteButton],    a[flowbiteButton]  ", ["flowbiteButton"], { "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, [{ directive: typeof i1.NgpButton; inputs: { "disabled": "disabled"; }; outputs: {}; }, { directive: typeof i2.NgpFocus; inputs: { "ngpFocusDisabled": "focusDisabled"; }; outputs: { "ngpFocus": "ngpFocus"; }; }, { directive: typeof BaseButton; inputs: { "color": "color"; "size": "size"; "pill": "pill"; "outline": "outline"; }; outputs: {}; }]>;
}

declare const FlowbiteButtonStateToken: _angular_core.InjectionToken<Button>;
declare const provideFlowbiteButtonState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteButtonState: <U = {
    readonly config: flowbite_angular_button.FlowbiteButtonConfig;
    readonly baseButtonState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: /*elided*/ any;
        readonly color: /*elided*/ any;
        readonly size: /*elided*/ any;
        readonly pill: /*elided*/ any;
        readonly outline: /*elided*/ any;
        readonly state: /*elided*/ any;
    }>>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            focus?: string | undefined;
            disabled?: string | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
                xl?: string | undefined;
            } | undefined;
            pill?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
            colorOutline?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly state: ng_primitives_state.CreatedState<Button>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteButtonState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

declare const FlowbiteBaseButtonStateToken: _angular_core.InjectionToken<BaseButton>;
declare const provideFlowbiteBaseButtonState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteBaseButtonState: <U = {
    readonly config: flowbite_angular_button.FlowbiteBaseButtonConfig;
    readonly color: _angular_core.InputSignal<keyof flowbite_angular_button.FlowbiteBaseButtonColors>;
    readonly size: _angular_core.InputSignal<keyof flowbite_angular_button.FlowbiteBaseButtonSizes>;
    readonly pill: _angular_core.InputSignalWithTransform<boolean, unknown>;
    readonly outline: _angular_core.InputSignalWithTransform<boolean, unknown>;
    readonly state: ng_primitives_state.CreatedState<BaseButton>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteBaseButtonState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

export { BaseButton, Button, FlowbiteBaseButtonConfigToken, FlowbiteBaseButtonStateToken, FlowbiteButtonConfigToken, FlowbiteButtonStateToken, defaultFlowbiteBaseButtonConfig, defaultFlowbiteButtonConfig, flowbiteBaseButtonState, flowbiteButtonState, flowbiteButtonTheme, injectFlowbiteBaseButtonConfig, injectFlowbiteBaseButtonState, injectFlowbiteButtonConfig, injectFlowbiteButtonState, provideFlowbiteBaseButtonConfig, provideFlowbiteBaseButtonState, provideFlowbiteButtonConfig, provideFlowbiteButtonState };
export type { FlowbiteBaseButtonColors, FlowbiteBaseButtonConfig, FlowbiteBaseButtonSizes, FlowbiteButtonConfig, FlowbiteButtonHostTheme, FlowbiteButtonTheme };
