import * as ng_primitives_state from 'ng-primitives/state';
import * as _angular_core from '@angular/core';
import { InjectionToken, Provider } from '@angular/core';
import * as flowbite_angular_card from 'flowbite-angular/card';
import { FlowbiteColors, ColorToTheme, FlowbiteSizes, DeepPartial } from 'flowbite-angular';

interface FlowbiteCardOrientation {
    vertical: string;
    horizontal: string;
}
interface FLowbiteCardColors extends Pick<FlowbiteColors, 'default' | 'info' | 'failure' | 'success' | 'warning' | 'primary'> {
    [key: string]: ColorToTheme;
}
interface FlowbiteCardSizes extends Pick<FlowbiteSizes, 'xs' | 'sm' | 'md' | 'lg' | 'xl'> {
    [key: string]: string;
}
interface FlowbiteCardTheme {
    host: FlowbiteCardHostTheme;
}
interface FlowbiteCardHostTheme {
    base: string;
    transition: string;
    orientation: FlowbiteCardOrientation;
    color: FLowbiteCardColors;
    size: FlowbiteCardSizes;
}
declare const flowbiteCardTheme: FlowbiteCardTheme;

interface FlowbiteCardConfig {
    /**
     * The default theme of card
     */
    baseTheme: FlowbiteCardTheme;
    /**
     * The default color of card
     */
    color: keyof FLowbiteCardColors;
    /**
     * The default size of card
     */
    size: keyof FlowbiteCardSizes;
    /**
     * The default orientation of card
     */
    orientation: keyof FlowbiteCardOrientation;
    /**
     * The custom theme of card
     */
    customTheme: DeepPartial<FlowbiteCardTheme>;
}
declare const defaultFlowbiteCardConfig: FlowbiteCardConfig;
declare const FlowbiteCardConfigToken: InjectionToken<FlowbiteCardConfig>;
/**
 * Provide the default Card configuration
 * @param config The Card configuration
 * @returns The provider
 */
declare const provideFlowbiteCardConfig: (config: Partial<FlowbiteCardConfig>) => Provider[];
/**
 * Inject the Card configuration
 * @see {@link defaultFlowbiteCardConfig}
 * @returns The configuration
 */
declare const injectFlowbiteCardConfig: () => FlowbiteCardConfig;

declare class Card {
    readonly config: FlowbiteCardConfig;
    /**
     * @see {@link injectFlowbiteCardConfig}
     */
    readonly color: _angular_core.InputSignal<keyof flowbite_angular_card.FLowbiteCardColors>;
    /**
     * @see {@link injectFlowbiteCardConfig}
     */
    readonly size: _angular_core.InputSignal<keyof flowbite_angular_card.FlowbiteCardSizes>;
    /**
     * @see {@link injectFlowbiteCardConfig}
     */
    readonly orientation: _angular_core.InputSignal<keyof flowbite_angular_card.FlowbiteCardOrientation>;
    /**
     * @see {@link injectFlowbiteCardConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            orientation?: {
                vertical?: string | undefined;
                horizontal?: string | undefined;
            } | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
                xl?: string | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<Card>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<Card, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<Card, "    [flowbiteCard]  ", ["flowbiteCard"], { "color": { "alias": "color"; "required": false; "isSignal": true; }; "size": { "alias": "size"; "required": false; "isSignal": true; }; "orientation": { "alias": "orientation"; "required": false; "isSignal": true; }; "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, never>;
}

declare const FlowbiteCardStateToken: _angular_core.InjectionToken<Card>;
declare const provideFlowbiteCardState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteCardState: <U = {
    readonly config: flowbite_angular_card.FlowbiteCardConfig;
    readonly color: _angular_core.InputSignal<keyof flowbite_angular_card.FLowbiteCardColors>;
    readonly size: _angular_core.InputSignal<keyof flowbite_angular_card.FlowbiteCardSizes>;
    readonly orientation: _angular_core.InputSignal<keyof flowbite_angular_card.FlowbiteCardOrientation>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            orientation?: {
                vertical?: string | undefined;
                horizontal?: string | undefined;
            } | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
                xl?: string | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<Card>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteCardState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

interface FlowbiteCardHeaderTheme {
    host: FlowbiteCardHeaderHostTheme;
}
interface FlowbiteCardHeaderHostTheme {
    base: string;
    transition: string;
    color: FLowbiteCardColors;
}
declare const flowbiteCardHeaderTheme: FlowbiteCardHeaderTheme;

interface FlowbiteCardHeaderConfig {
    /**
     * The default theme of CardHeader
     */
    baseTheme: FlowbiteCardHeaderTheme;
    /**
     * The custom theme of CardHeader
     */
    customTheme: DeepPartial<FlowbiteCardHeaderTheme>;
}
declare const defaultFlowbiteCardHeaderConfig: FlowbiteCardHeaderConfig;
declare const FlowbiteCardHeaderConfigToken: InjectionToken<FlowbiteCardHeaderConfig>;
/**
 * Provide the default CardHeader configuration
 * @param config The CardHeader configuration
 * @returns The provider
 */
declare const provideFlowbiteCardHeaderConfig: (config: Partial<FlowbiteCardHeaderConfig>) => Provider[];
/**
 * Inject the CardHeader configuration
 * @see {@link defaultFlowbiteCardHeaderConfig}
 * @returns The configuration
 */
declare const injectFlowbiteCardHeaderConfig: () => FlowbiteCardHeaderConfig;

declare class CardHeader {
    readonly config: FlowbiteCardHeaderConfig;
    readonly cardState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: flowbite_angular_card.FlowbiteCardConfig;
        readonly color: _angular_core.InputSignal<keyof flowbite_angular_card.FLowbiteCardColors>;
        readonly size: _angular_core.InputSignal<keyof flowbite_angular_card.FlowbiteCardSizes>;
        readonly orientation: _angular_core.InputSignal<keyof flowbite_angular_card.FlowbiteCardOrientation>;
        readonly customTheme: _angular_core.InputSignal<{
            host?: {
                base?: string | undefined;
                transition?: string | undefined;
                orientation?: {
                    vertical?: string | undefined;
                    horizontal?: string | undefined;
                } | undefined;
                color?: {
                    [x: string]: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    default?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    info?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    failure?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    success?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    warning?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    primary?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                } | undefined;
                size?: {
                    [x: string]: string | undefined;
                    xs?: string | undefined;
                    sm?: string | undefined;
                    md?: string | undefined;
                    lg?: string | undefined;
                    xl?: string | undefined;
                } | undefined;
            } | undefined;
        }>;
        readonly theme: _angular_core.Signal<{
            host: {
                root: string;
            };
        }>;
        readonly state: ng_primitives_state.CreatedState<flowbite_angular_card.Card>;
    }>>;
    /**
     * @see {@link injectFlowbiteCardHeaderConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<CardHeader>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<CardHeader, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<CardHeader, "    [flowbiteCardHeader]  ", ["flowbiteCardHeader"], { "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, never>;
}

declare const FlowbiteCardHeaderStateToken: _angular_core.InjectionToken<CardHeader>;
declare const provideFlowbiteCardHeaderState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteCardHeaderState: <U = {
    readonly config: flowbite_angular_card.FlowbiteCardHeaderConfig;
    readonly cardState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: /*elided*/ any;
        readonly color: /*elided*/ any;
        readonly size: /*elided*/ any;
        readonly orientation: /*elided*/ any;
        readonly customTheme: /*elided*/ any;
        readonly theme: /*elided*/ any;
        readonly state: /*elided*/ any;
    }>>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<CardHeader>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteCardHeaderState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

interface FlowbiteCardContentTheme {
    host: FlowbiteCardContentHostTheme;
}
interface FlowbiteCardContentHostTheme {
    base: string;
    transition: string;
    color: FLowbiteCardColors;
    size: FlowbiteCardSizes;
}
declare const flowbiteCardContentTheme: FlowbiteCardContentTheme;

interface FlowbiteCardContentConfig {
    /**
     * The default theme of CardContent
     */
    baseTheme: FlowbiteCardContentTheme;
    /**
     * The custom theme of CardContent
     */
    customTheme: DeepPartial<FlowbiteCardContentTheme>;
}
declare const defaultFlowbiteCardContentConfig: FlowbiteCardContentConfig;
declare const FlowbiteCardContentConfigToken: InjectionToken<FlowbiteCardContentConfig>;
/**
 * Provide the default CardContent configuration
 * @param config The CardContent configuration
 * @returns The provider
 */
declare const provideFlowbiteCardContentConfig: (config: Partial<FlowbiteCardContentConfig>) => Provider[];
/**
 * Inject the CardContent configuration
 * @see {@link defaultFlowbiteCardContentConfig}
 * @returns The configuration
 */
declare const injectFlowbiteCardContentConfig: () => FlowbiteCardContentConfig;

declare class CardContent {
    readonly config: FlowbiteCardContentConfig;
    readonly cardState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: flowbite_angular_card.FlowbiteCardConfig;
        readonly color: _angular_core.InputSignal<keyof flowbite_angular_card.FLowbiteCardColors>;
        readonly size: _angular_core.InputSignal<keyof flowbite_angular_card.FlowbiteCardSizes>;
        readonly orientation: _angular_core.InputSignal<keyof flowbite_angular_card.FlowbiteCardOrientation>;
        readonly customTheme: _angular_core.InputSignal<{
            host?: {
                base?: string | undefined;
                transition?: string | undefined;
                orientation?: {
                    vertical?: string | undefined;
                    horizontal?: string | undefined;
                } | undefined;
                color?: {
                    [x: string]: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    default?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    info?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    failure?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    success?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    warning?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    primary?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                } | undefined;
                size?: {
                    [x: string]: string | undefined;
                    xs?: string | undefined;
                    sm?: string | undefined;
                    md?: string | undefined;
                    lg?: string | undefined;
                    xl?: string | undefined;
                } | undefined;
            } | undefined;
        }>;
        readonly theme: _angular_core.Signal<{
            host: {
                root: string;
            };
        }>;
        readonly state: ng_primitives_state.CreatedState<flowbite_angular_card.Card>;
    }>>;
    /**
     * @see {@link injectFlowbiteCardContentConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
                xl?: string | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<CardContent>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<CardContent, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<CardContent, "    [flowbiteCardContent]  ", ["flowbiteCardContent"], { "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, never>;
}

declare const FlowbiteCardContentStateToken: _angular_core.InjectionToken<CardContent>;
declare const provideFlowbiteCardContentState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteCardContentState: <U = {
    readonly config: flowbite_angular_card.FlowbiteCardContentConfig;
    readonly cardState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: /*elided*/ any;
        readonly color: /*elided*/ any;
        readonly size: /*elided*/ any;
        readonly orientation: /*elided*/ any;
        readonly customTheme: /*elided*/ any;
        readonly theme: /*elided*/ any;
        readonly state: /*elided*/ any;
    }>>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
                xl?: string | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<CardContent>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteCardContentState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

export { Card, CardContent, CardHeader, FlowbiteCardConfigToken, FlowbiteCardContentConfigToken, FlowbiteCardContentStateToken, FlowbiteCardHeaderConfigToken, FlowbiteCardHeaderStateToken, FlowbiteCardStateToken, defaultFlowbiteCardConfig, defaultFlowbiteCardContentConfig, defaultFlowbiteCardHeaderConfig, flowbiteCardContentState, flowbiteCardContentTheme, flowbiteCardHeaderState, flowbiteCardHeaderTheme, flowbiteCardState, flowbiteCardTheme, injectFlowbiteCardConfig, injectFlowbiteCardContentConfig, injectFlowbiteCardContentState, injectFlowbiteCardHeaderConfig, injectFlowbiteCardHeaderState, injectFlowbiteCardState, provideFlowbiteCardConfig, provideFlowbiteCardContentConfig, provideFlowbiteCardContentState, provideFlowbiteCardHeaderConfig, provideFlowbiteCardHeaderState, provideFlowbiteCardState };
export type { FLowbiteCardColors, FlowbiteCardConfig, FlowbiteCardContentConfig, FlowbiteCardContentHostTheme, FlowbiteCardContentTheme, FlowbiteCardHeaderConfig, FlowbiteCardHeaderHostTheme, FlowbiteCardHeaderTheme, FlowbiteCardHostTheme, FlowbiteCardOrientation, FlowbiteCardSizes, FlowbiteCardTheme };
