import * as ng_primitives_state from 'ng-primitives/state';
import * as _angular_core from '@angular/core';
import { InjectionToken, Provider } from '@angular/core';
import * as flowbite_angular_dropdown from 'flowbite-angular/dropdown';
import { FlowbiteColors, ColorToTheme, DeepPartial } from 'flowbite-angular';
import * as i1 from 'ng-primitives/menu';
import * as i2 from 'ng-primitives/interactions';

interface FLowbiteDropdownColors extends Pick<FlowbiteColors, 'default' | 'info' | 'failure' | 'success' | 'warning' | 'primary'> {
    [key: string]: ColorToTheme;
}
interface FlowbiteDropdownTheme {
    host: FlowbiteDropdownHostTheme;
}
interface FlowbiteDropdownHostTheme {
    base: string;
    transition: string;
    color: FLowbiteDropdownColors;
}
declare const flowbiteDropdownTheme: FlowbiteDropdownTheme;

interface FlowbiteDropdownConfig {
    baseTheme: FlowbiteDropdownTheme;
    /**
     * The custom color of dropdown
     */
    color: keyof FLowbiteDropdownColors;
    /**
     * The custom theme of dropdown
     */
    customTheme: DeepPartial<FlowbiteDropdownTheme>;
}
declare const defaultFlowbiteDropdownConfig: FlowbiteDropdownConfig;
declare const FlowbiteDropdownConfigToken: InjectionToken<FlowbiteDropdownConfig>;
/**
 * Provide the default Dropdown configuration
 * @param config The Dropdown configuration
 * @returns The provider
 */
declare const provideFlowbiteDropdownConfig: (config: Partial<FlowbiteDropdownConfig>) => Provider[];
/**
 * Inject the Dropdown configuration
 * @see {@link defaultFlowbiteDropdownConfig}
 * @returns The configuration
 */
declare const injectFlowbiteDropdownConfig: () => FlowbiteDropdownConfig;

declare class Dropdown {
    readonly config: FlowbiteDropdownConfig;
    /**
     * @see {@link injectFlowbiteDropdownConfig}
     */
    readonly color: _angular_core.InputSignal<keyof flowbite_angular_dropdown.FLowbiteDropdownColors>;
    /**
     * @see {@link injectFlowbiteDropdownConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<Dropdown>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<Dropdown, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<Dropdown, "    div[flowbiteDropdown]  ", ["flowbiteDropdown"], { "color": { "alias": "color"; "required": false; "isSignal": true; }; "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, [{ directive: typeof i1.NgpMenu; inputs: {}; outputs: {}; }]>;
}

declare const FlowbiteDropdownStateToken: _angular_core.InjectionToken<Dropdown>;
declare const provideFlowbiteDropdownState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteDropdownState: <U = {
    readonly config: flowbite_angular_dropdown.FlowbiteDropdownConfig;
    readonly color: _angular_core.InputSignal<keyof flowbite_angular_dropdown.FLowbiteDropdownColors>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<Dropdown>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteDropdownState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

interface FlowbiteDropdownItemTheme {
    host: FlowbiteDropdownItemHostTheme;
}
interface FlowbiteDropdownItemHostTheme {
    base: string;
    transition: string;
    color: FLowbiteDropdownColors;
}
declare const flowbiteDropdownItemTheme: FlowbiteDropdownItemTheme;

interface FlowbiteDropdownItemConfig {
    baseTheme: FlowbiteDropdownItemTheme;
    /**
     * The custom theme of dropdown item
     */
    customTheme: DeepPartial<FlowbiteDropdownItemTheme>;
}
declare const defaultFlowbiteDropdownItemConfig: FlowbiteDropdownItemConfig;
declare const FlowbiteDropdownItemConfigToken: InjectionToken<FlowbiteDropdownItemConfig>;
/**
 * Provide the default Dropdown Item configuration
 * @param config The Dropdown Item configuration
 * @returns The provider
 */
declare const provideFlowbiteDropdownItemConfig: (config: Partial<FlowbiteDropdownItemConfig>) => Provider[];
/**
 * Inject the Dropdown Item configuration
 * @see {@link defaultFlowbiteDropdownItemConfig}
 * @returns The configuration
 */
declare const injectFlowbiteDropdownItemConfig: () => FlowbiteDropdownItemConfig;

declare class DropdownItem {
    readonly config: FlowbiteDropdownItemConfig;
    readonly dropdownState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: flowbite_angular_dropdown.FlowbiteDropdownConfig;
        readonly color: _angular_core.InputSignal<keyof flowbite_angular_dropdown.FLowbiteDropdownColors>;
        readonly customTheme: _angular_core.InputSignal<{
            host?: {
                base?: string | undefined;
                transition?: string | undefined;
                color?: {
                    [x: string]: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    default?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    info?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    failure?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    success?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    warning?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    primary?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                } | undefined;
            } | undefined;
        }>;
        readonly theme: _angular_core.Signal<{
            host: {
                root: string;
            };
        }>;
        readonly state: ng_primitives_state.CreatedState<flowbite_angular_dropdown.Dropdown>;
    }>>;
    /**
     * @see {@link injectFlowbiteDropdownItemConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<DropdownItem>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<DropdownItem, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<DropdownItem, "    li[flowbiteDropdownItem]  ", ["flowbiteDropdownItem"], { "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, [{ directive: typeof i1.NgpMenuItem; inputs: {}; outputs: {}; }, { directive: typeof i2.NgpFocus; inputs: {}; outputs: {}; }]>;
}

declare const FlowbiteDropdownItemStateToken: _angular_core.InjectionToken<DropdownItem>;
declare const provideFlowbiteDropdownItemState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteDropdownItemState: <U = {
    readonly config: flowbite_angular_dropdown.FlowbiteDropdownItemConfig;
    readonly dropdownState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: /*elided*/ any;
        readonly color: /*elided*/ any;
        readonly customTheme: /*elided*/ any;
        readonly theme: /*elided*/ any;
        readonly state: /*elided*/ any;
    }>>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<DropdownItem>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteDropdownItemState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

interface FlowbiteDropdownContentTheme {
    host: FlowbiteDropdownContentHostTheme;
}
interface FlowbiteDropdownContentHostTheme {
    base: string;
    transition: string;
    color: FLowbiteDropdownColors;
}
declare const flowbiteDropdownContentTheme: FlowbiteDropdownContentTheme;

interface FlowbiteDropdownContentConfig {
    /**
     * The default theme of DropdownContent
     */
    baseTheme: FlowbiteDropdownContentTheme;
    /**
     * The custom theme of DropdownContent
     */
    customTheme: DeepPartial<FlowbiteDropdownContentTheme>;
}
declare const defaultFlowbiteDropdownContentConfig: FlowbiteDropdownContentConfig;
declare const FlowbiteDropdownContentConfigToken: InjectionToken<FlowbiteDropdownContentConfig>;
/**
 * Provide the default DropdownContent configuration
 * @param config The DropdownContent configuration
 * @returns The provider
 */
declare const provideFlowbiteDropdownContentConfig: (config: Partial<FlowbiteDropdownContentConfig>) => Provider[];
/**
 * Inject the DropdownContent configuration
 * @see {@link defaultFlowbiteDropdownContentConfig}
 * @returns The configuration
 */
declare const injectFlowbiteDropdownContentConfig: () => FlowbiteDropdownContentConfig;

declare class DropdownContent {
    readonly config: FlowbiteDropdownContentConfig;
    readonly dropdownState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: flowbite_angular_dropdown.FlowbiteDropdownConfig;
        readonly color: _angular_core.InputSignal<keyof flowbite_angular_dropdown.FLowbiteDropdownColors>;
        readonly customTheme: _angular_core.InputSignal<{
            host?: {
                base?: string | undefined;
                transition?: string | undefined;
                color?: {
                    [x: string]: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    default?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    info?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    failure?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    success?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    warning?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    primary?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                } | undefined;
            } | undefined;
        }>;
        readonly theme: _angular_core.Signal<{
            host: {
                root: string;
            };
        }>;
        readonly state: ng_primitives_state.CreatedState<flowbite_angular_dropdown.Dropdown>;
    }>>;
    /**
     * @see {@link injectFlowbiteDropdownContentConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<DropdownContent>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<DropdownContent, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<DropdownContent, "    ul[flowbiteDropdownContent]  ", ["flowbiteDropdownContent"], { "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, never>;
}

declare const FlowbiteDropdownContentStateToken: _angular_core.InjectionToken<DropdownContent>;
declare const provideFlowbiteDropdownContentState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteDropdownContentState: <U = {
    readonly config: flowbite_angular_dropdown.FlowbiteDropdownContentConfig;
    readonly dropdownState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: /*elided*/ any;
        readonly color: /*elided*/ any;
        readonly customTheme: /*elided*/ any;
        readonly theme: /*elided*/ any;
        readonly state: /*elided*/ any;
    }>>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<DropdownContent>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteDropdownContentState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

export { Dropdown, DropdownContent, DropdownItem, FlowbiteDropdownConfigToken, FlowbiteDropdownContentConfigToken, FlowbiteDropdownContentStateToken, FlowbiteDropdownItemConfigToken, FlowbiteDropdownItemStateToken, FlowbiteDropdownStateToken, defaultFlowbiteDropdownConfig, defaultFlowbiteDropdownContentConfig, defaultFlowbiteDropdownItemConfig, flowbiteDropdownContentState, flowbiteDropdownContentTheme, flowbiteDropdownItemState, flowbiteDropdownItemTheme, flowbiteDropdownState, flowbiteDropdownTheme, injectFlowbiteDropdownConfig, injectFlowbiteDropdownContentConfig, injectFlowbiteDropdownContentState, injectFlowbiteDropdownItemConfig, injectFlowbiteDropdownItemState, injectFlowbiteDropdownState, provideFlowbiteDropdownConfig, provideFlowbiteDropdownContentConfig, provideFlowbiteDropdownContentState, provideFlowbiteDropdownItemConfig, provideFlowbiteDropdownItemState, provideFlowbiteDropdownState };
export type { FLowbiteDropdownColors, FlowbiteDropdownConfig, FlowbiteDropdownContentConfig, FlowbiteDropdownContentHostTheme, FlowbiteDropdownContentTheme, FlowbiteDropdownHostTheme, FlowbiteDropdownItemConfig, FlowbiteDropdownItemHostTheme, FlowbiteDropdownItemTheme, FlowbiteDropdownTheme };
