import * as ng_primitives_state from 'ng-primitives/state';
import * as flowbite_angular_icon from 'flowbite-angular/icon';
import * as _angular_core from '@angular/core';
import { InjectionToken, Provider, OnDestroy } from '@angular/core';
import { FlowbiteColors, ColorToTheme, DeepPartial } from 'flowbite-angular';
import * as _ng_icons_core from '@ng-icons/core';
import { IconType } from '@ng-icons/core';

interface FlowbiteIconColors extends FlowbiteColors {
    [key: string]: ColorToTheme;
}
interface FlowbiteIconTheme {
    host: FlowbiteIconHostTheme;
}
interface FlowbiteIconHostTheme {
    base: string;
    transition: string;
    color: FlowbiteIconColors;
}
declare const flowbiteIconTheme: FlowbiteIconTheme;

interface FlowbiteIconConfig {
    /**
     * The default theme of icon
     */
    baseTheme: FlowbiteIconTheme;
    /**
     * The default color of icon
     */
    color: keyof FlowbiteIconColors;
    /**
     * The custom theme of icon
     */
    customTheme: DeepPartial<FlowbiteIconTheme>;
}
declare const defaultFlowbiteIconConfig: FlowbiteIconConfig;
declare const FlowbiteIconConfigToken: InjectionToken<FlowbiteIconConfig>;
/**
 * Provide the default Icon configuration
 * @param config The Icon configuration
 * @returns The provider
 */
declare const provideFlowbiteIconConfig: (config: Partial<FlowbiteIconConfig>) => Provider[];
/**
 * Inject the Icon configuration
 * @see {@link defaultFlowbiteIconConfig}
 * @returns The configuration
 */
declare const injectFlowbiteIconConfig: () => FlowbiteIconConfig;

declare class Icon implements OnDestroy {
    readonly config: FlowbiteIconConfig;
    /** Access the icons */
    private readonly icons;
    /** Access the icon loader if defined */
    private readonly loader;
    /** Access the icon cache if defined */
    private readonly cache;
    /** Access the pre-processor */
    private readonly preProcessor;
    /** Access the post-processor */
    private readonly postProcessor;
    /** Access the injector */
    private readonly injector;
    /** Access the renderer */
    private readonly renderer;
    /** Determine the platform we are rendering on */
    private readonly platform;
    /** Access the element ref */
    private readonly elementRef;
    /** A unique id for this instance */
    private readonly uniqueId;
    /** Define the name of the icon to display */
    readonly name: _angular_core.InputSignal<IconType | undefined>;
    /** Define the svg of the icon to display */
    readonly svg: _angular_core.InputSignal<string | undefined>;
    /**
     * @see {@link injectFlowbiteIconConfig}
     */
    readonly color: _angular_core.InputSignal<keyof flowbite_angular_icon.FlowbiteIconColors>;
    /**
     * @see {@link injectFlowbiteIconConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                dark?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                light?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                blue?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                cyan?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                gray?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                green?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                indigo?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                lime?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                pink?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                purple?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                red?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                teal?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                yellow?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    /** Store the inserted SVG */
    private svgElement?;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    protected readonly state: ng_primitives_state.CreatedState<Icon>;
    constructor();
    ngOnDestroy(): void;
    private updateIcon;
    private setSvg;
    private replaceIds;
    /**
     * Request the icon from the loader.
     * @param name The name of the icon to load.
     * @returns The SVG content for a given icon name.
     */
    private requestIconFromLoader;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<Icon, never>;
    static ɵcmp: _angular_core.ɵɵComponentDeclaration<Icon, "flowbite-icon", ["flowbiteIcon"], { "name": { "alias": "name"; "required": false; "isSignal": true; }; "svg": { "alias": "svg"; "required": false; "isSignal": true; }; "color": { "alias": "color"; "required": false; "isSignal": true; }; "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, never>;
}

declare const FlowbiteIconStateToken: InjectionToken<Icon>;
declare const provideFlowbiteIconState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteIconState: <U = {
    readonly config: flowbite_angular_icon.FlowbiteIconConfig;
    readonly icons: Record<string, string>[];
    readonly loader: _ng_icons_core.NgIconLoader | null;
    readonly cache: _ng_icons_core.NgIconLoaderCache | null;
    readonly preProcessor: NgIconPreProcessor;
    readonly postProcessor: NgIconPostProcessor;
    readonly injector: _angular_core.Injector;
    readonly renderer: _angular_core.Renderer2;
    readonly platform: Object;
    readonly elementRef: _angular_core.ElementRef<HTMLElement>;
    readonly uniqueId: number;
    readonly name: _angular_core.InputSignal<_ng_icons_core.IconType | undefined>;
    readonly svg: _angular_core.InputSignal<string | undefined>;
    readonly color: _angular_core.InputSignal<keyof flowbite_angular_icon.FlowbiteIconColors>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                dark?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                light?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                blue?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                cyan?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                gray?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                green?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                indigo?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                lime?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                pink?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                purple?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                red?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                teal?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                yellow?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    svgElement?: SVGElement | undefined;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<Icon>;
    ngOnDestroy: () => void;
    updateIcon: () => Promise<void>;
    setSvg: (svg: string) => void;
    replaceIds: (svg: string) => string;
    requestIconFromLoader: (name: string) => Promise<string>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteIconState: <U>(state: U) => ng_primitives_state.CreatedState<U>;
type NgIconPreProcessor = (icon: string) => string;
type NgIconPostProcessor = (element: HTMLElement | SVGElement) => void;
declare const NgIconPreProcessorToken: InjectionToken<NgIconPreProcessor>;
declare const NgIconPostProcessorToken: InjectionToken<NgIconPostProcessor>;
declare function injectNgIconPreProcessor(): NgIconPreProcessor;
declare function injectNgIconPostProcessor(): NgIconPostProcessor;

export { FlowbiteIconConfigToken, FlowbiteIconStateToken, Icon, NgIconPostProcessorToken, NgIconPreProcessorToken, defaultFlowbiteIconConfig, flowbiteIconState, flowbiteIconTheme, injectFlowbiteIconConfig, injectFlowbiteIconState, injectNgIconPostProcessor, injectNgIconPreProcessor, provideFlowbiteIconConfig, provideFlowbiteIconState };
export type { FlowbiteIconColors, FlowbiteIconConfig, FlowbiteIconHostTheme, FlowbiteIconTheme, NgIconPostProcessor, NgIconPreProcessor };
