import * as ng_primitives_state from 'ng-primitives/state';
import * as _angular_core from '@angular/core';
import { InjectionToken, Provider } from '@angular/core';
import * as flowbite_angular_indicator from 'flowbite-angular/indicator';
import { FlowbiteBoolean, FlowbiteColors, ColorToTheme, FlowbiteSizes, FlowbitePositions, DeepPartial } from 'flowbite-angular';

interface FlowbiteIndicatorColors extends Pick<FlowbiteColors, 'default' | 'info' | 'failure' | 'success' | 'warning' | 'primary'> {
    [key: string]: ColorToTheme;
}
interface FlowbiteIndicatorSizes extends Pick<FlowbiteSizes, 'xs' | 'sm' | 'md' | 'lg' | 'xl'> {
    [key: string]: string;
}
interface FlowbiteIndicatorPositions extends FlowbitePositions {
    [key: string]: string;
}
interface FlowbiteIndicatorTheme {
    host: FlowbiteIndicatorHostTheme;
}
interface FlowbiteIndicatorHostTheme {
    base: string;
    transition: string;
    border: FlowbiteBoolean;
    color: FlowbiteIndicatorColors;
    size: FlowbiteIndicatorSizes;
    position: FlowbiteIndicatorPositions;
}
declare const flowbiteIndicatorTheme: FlowbiteIndicatorTheme;

interface FlowbiteIndicatorConfig {
    /**
     * The default theme of indicator
     */
    baseTheme: FlowbiteIndicatorTheme;
    /**
     * The default color of indicator
     */
    color: keyof FlowbiteIndicatorColors;
    /**
     * The default size of indicator
     */
    size: keyof FlowbiteIndicatorSizes;
    /**
     * Whether the indicator has border
     */
    border: boolean;
    /**
     * The default position of indicator
     */
    position: keyof FlowbiteIndicatorPositions | undefined;
    /**
     * The custom theme of indicator
     */
    customTheme: DeepPartial<FlowbiteIndicatorTheme>;
}
declare const defaultFlowbiteIndicatorConfig: FlowbiteIndicatorConfig;
declare const FlowbiteIndicatorConfigToken: InjectionToken<FlowbiteIndicatorConfig>;
/**
 * Provide the default Indicator configuration
 * @param config The Indicator configuration
 * @returns The provider
 */
declare const provideFlowbiteIndicatorConfig: (config: Partial<FlowbiteIndicatorConfig>) => Provider[];
/**
 * Inject the Indicator configuration
 * @see {@link defaultFlowbiteIndicatorConfig}
 * @returns The configuration
 */
declare const injectFlowbiteIndicatorConfig: () => FlowbiteIndicatorConfig;

declare class Indicator {
    readonly config: FlowbiteIndicatorConfig;
    /**
     * @see {@link injectFlowbiteIndicatorConfig}
     */
    readonly color: _angular_core.InputSignal<keyof flowbite_angular_indicator.FlowbiteIndicatorColors>;
    /**
     * @see {@link injectFlowbiteIndicatorConfig}
     */
    readonly size: _angular_core.InputSignal<keyof flowbite_angular_indicator.FlowbiteIndicatorSizes>;
    /**
     * @see {@link injectFlowbiteIndicatorConfig}
     */
    readonly border: _angular_core.InputSignalWithTransform<boolean, unknown>;
    /**
     * @see {@link injectFlowbiteIndicatorConfig}
     */
    readonly position: _angular_core.InputSignal<keyof flowbite_angular_indicator.FlowbiteIndicatorPositions | undefined>;
    /**
     * @see {@link injectFlowbiteIndicatorConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            border?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
                xl?: string | undefined;
            } | undefined;
            position?: {
                [x: string]: string | undefined;
                'bottom-left'?: string | undefined;
                'bottom-right'?: string | undefined;
                'bottom-center'?: string | undefined;
                'top-left'?: string | undefined;
                'top-center'?: string | undefined;
                'top-right'?: string | undefined;
                'center-left'?: string | undefined;
                center?: string | undefined;
                'center-right'?: string | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<Indicator>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<Indicator, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<Indicator, "    span[flowbiteIndicator]  ", ["flowbiteIndicator"], { "color": { "alias": "color"; "required": false; "isSignal": true; }; "size": { "alias": "size"; "required": false; "isSignal": true; }; "border": { "alias": "border"; "required": false; "isSignal": true; }; "position": { "alias": "position"; "required": false; "isSignal": true; }; "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, never>;
}

declare const FlowbiteIndicatorStateToken: _angular_core.InjectionToken<Indicator>;
declare const provideFlowbiteIndicatorState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteIndicatorState: <U = {
    readonly config: flowbite_angular_indicator.FlowbiteIndicatorConfig;
    readonly color: _angular_core.InputSignal<keyof flowbite_angular_indicator.FlowbiteIndicatorColors>;
    readonly size: _angular_core.InputSignal<keyof flowbite_angular_indicator.FlowbiteIndicatorSizes>;
    readonly border: _angular_core.InputSignalWithTransform<boolean, unknown>;
    readonly position: _angular_core.InputSignal<keyof flowbite_angular_indicator.FlowbiteIndicatorPositions | undefined>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            border?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
                xl?: string | undefined;
            } | undefined;
            position?: {
                [x: string]: string | undefined;
                'bottom-left'?: string | undefined;
                'bottom-right'?: string | undefined;
                'bottom-center'?: string | undefined;
                'top-left'?: string | undefined;
                'top-center'?: string | undefined;
                'top-right'?: string | undefined;
                'center-left'?: string | undefined;
                center?: string | undefined;
                'center-right'?: string | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<Indicator>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteIndicatorState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

export { FlowbiteIndicatorConfigToken, FlowbiteIndicatorStateToken, Indicator, defaultFlowbiteIndicatorConfig, flowbiteIndicatorState, flowbiteIndicatorTheme, injectFlowbiteIndicatorConfig, injectFlowbiteIndicatorState, provideFlowbiteIndicatorConfig, provideFlowbiteIndicatorState };
export type { FlowbiteIndicatorColors, FlowbiteIndicatorConfig, FlowbiteIndicatorHostTheme, FlowbiteIndicatorPositions, FlowbiteIndicatorSizes, FlowbiteIndicatorTheme };
