import * as ng_primitives_state from 'ng-primitives/state';
import * as _angular_core from '@angular/core';
import { InjectionToken, Provider } from '@angular/core';
import { FlowbiteBoolean, FlowbiteColors, ColorToTheme, DeepPartial } from 'flowbite-angular';
import * as _angular_cdk_coercion from '@angular/cdk/coercion';
import { BooleanInput } from '@angular/cdk/coercion';
import * as flowbite_angular_navbar from 'flowbite-angular/navbar';
import * as flowbite_angular_button from 'flowbite-angular/button';
import { FlowbiteBaseButtonSizes, FlowbiteBaseButtonColors, BaseButton } from 'flowbite-angular/button';
import * as i2 from 'ng-primitives/button';
import * as i3 from 'ng-primitives/interactions';

interface FlowbiteNavbarColors extends Pick<FlowbiteColors, 'default' | 'info' | 'failure' | 'success' | 'warning' | 'primary'> {
    [key: string]: ColorToTheme;
}
interface FlowbiteNavbarTheme {
    host: FlowbiteNavbarHostTheme;
    container: FlowbiteNavbarContainerTheme;
}
interface FlowbiteNavbarHostTheme {
    base: string;
    transition: string;
    fixed: FlowbiteBoolean;
    color: FlowbiteNavbarColors;
}
interface FlowbiteNavbarContainerTheme {
    base: string;
    transition: string;
}
declare const flowbiteNavbarTheme: FlowbiteNavbarTheme;

interface FlowbiteNavbarConfig {
    /**
     * The default theme of navbar
     */
    baseTheme: FlowbiteNavbarTheme;
    /**
     * Whether the navbar is fixed
     */
    fixed: boolean;
    /**
     * Whether the navbar is open
     */
    open: boolean;
    /**
     * The color of navbar
     */
    color: keyof FlowbiteNavbarColors;
    /**
     * The custom theme of navbar
     */
    customTheme: DeepPartial<FlowbiteNavbarTheme>;
}
declare const defaultFlowbiteNavbarConfig: FlowbiteNavbarConfig;
declare const FlowbiteNavbarConfigToken: InjectionToken<FlowbiteNavbarConfig>;
/**
 * Provide the default Navbar configuration
 * @param config The Navbar configuration
 * @returns The provider
 */
declare const provideFlowbiteNavbarConfig: (config: Partial<FlowbiteNavbarConfig>) => Provider[];
/**
 * Inject the Navbar configuration
 * @see {@link defaultFlowbiteNavbarConfig}
 * @returns The configuration
 */
declare const injectFlowbiteNavbarConfig: () => FlowbiteNavbarConfig;

declare class Navbar {
    protected readonly config: FlowbiteNavbarConfig;
    /**
     * @see {@link injectFlowbiteNavbarConfig}
     */
    readonly fixed: _angular_core.InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * @see {@link injectFlowbiteNavbarConfig}
     */
    readonly open: _angular_core.InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * @see {@link injectFlowbiteNavbarConfig}
     */
    readonly color: _angular_core.InputSignal<keyof FlowbiteNavbarColors>;
    /**
     * @see {@link injectFlowbiteNavbarConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            fixed?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
        container?: {
            base?: string | undefined;
            transition?: string | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
        container: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<Navbar>;
    /**
     * @internal
     */
    toggle(newState?: boolean): void;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<Navbar, never>;
    static ɵcmp: _angular_core.ɵɵComponentDeclaration<Navbar, "    nav[flowbiteNavbar]  ", ["flowbiteNavbar"], { "fixed": { "alias": "fixed"; "required": false; "isSignal": true; }; "open": { "alias": "open"; "required": false; "isSignal": true; }; "color": { "alias": "color"; "required": false; "isSignal": true; }; "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, ["*"], true, never>;
}

declare const FlowbiteNavbarStateToken: _angular_core.InjectionToken<Navbar>;
declare const provideFlowbiteNavbarState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteNavbarState: <U = {
    readonly config: flowbite_angular_navbar.FlowbiteNavbarConfig;
    readonly fixed: _angular_core.InputSignalWithTransform<boolean, _angular_cdk_coercion.BooleanInput>;
    readonly open: _angular_core.InputSignalWithTransform<boolean, _angular_cdk_coercion.BooleanInput>;
    readonly color: _angular_core.InputSignal<keyof flowbite_angular_navbar.FlowbiteNavbarColors>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            fixed?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
        container?: {
            base?: string | undefined;
            transition?: string | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
        container: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<Navbar>;
    toggle: (newState?: boolean) => void;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteNavbarState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

interface FlowbiteNavbarItemTheme {
    host: FlowbiteNavbarItemHostTheme;
}
interface FlowbiteNavbarItemHostTheme {
    base: string;
    transition: string;
    focus: string;
    disabled: string;
    size: FlowbiteBaseButtonSizes;
    pill: FlowbiteBoolean;
    color: FlowbiteBaseButtonColors;
    colorOutline: FlowbiteBaseButtonColors;
}
declare const flowbiteNavbarItemTheme: FlowbiteNavbarItemTheme;

interface FlowbiteNavbarItemConfig {
    /**
     * The default theme of navbar-item
     */
    baseTheme: FlowbiteNavbarItemTheme;
    /**
     * The custom theme of navbar-item
     */
    customTheme: DeepPartial<FlowbiteNavbarItemTheme>;
}
declare const defaultFlowbiteNavbarItemConfig: FlowbiteNavbarItemConfig;
declare const FlowbiteNavbarItemConfigToken: InjectionToken<FlowbiteNavbarItemConfig>;
/**
 * Provide the default NavbarItem configuration
 * @param config The NavbarItem configuration
 * @returns The provider
 */
declare const provideFlowbiteNavbarItemConfig: (config: Partial<FlowbiteNavbarItemConfig>) => Provider[];
/**
 * Inject the NavbarItem configuration
 * @see {@link defaultFlowbiteNavbarItemConfig}
 * @returns The configuration
 */
declare const injectFlowbiteNavbarItemConfig: () => FlowbiteNavbarItemConfig;

declare class NavbarItem {
    protected readonly config: FlowbiteNavbarItemConfig;
    protected readonly navbarState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: flowbite_angular_navbar.FlowbiteNavbarConfig;
        readonly fixed: _angular_core.InputSignalWithTransform<boolean, _angular_cdk_coercion.BooleanInput>;
        readonly open: _angular_core.InputSignalWithTransform<boolean, _angular_cdk_coercion.BooleanInput>;
        readonly color: _angular_core.InputSignal<keyof flowbite_angular_navbar.FlowbiteNavbarColors>;
        readonly customTheme: _angular_core.InputSignal<{
            host?: {
                base?: string | undefined;
                transition?: string | undefined;
                fixed?: {
                    off?: string | undefined;
                    on?: string | undefined;
                } | undefined;
                color?: {
                    [x: string]: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    default?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    info?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    failure?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    success?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    warning?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    primary?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                } | undefined;
            } | undefined;
            container?: {
                base?: string | undefined;
                transition?: string | undefined;
            } | undefined;
        }>;
        readonly theme: _angular_core.Signal<{
            host: {
                root: string;
            };
            container: {
                root: string;
            };
        }>;
        readonly state: ng_primitives_state.CreatedState<flowbite_angular_navbar.Navbar>;
        toggle: (newState?: boolean) => void;
    }>>;
    /**
     * @see {@link injectFlowbiteNavbarItemConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            focus?: string | undefined;
            disabled?: string | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
                xl?: string | undefined;
            } | undefined;
            pill?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
            colorOutline?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<NavbarItem>;
    /**
     * @internal
     */
    onClick(): void;
    /**
     * @internal
     */
    toggleNavbar(): void;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<NavbarItem, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<NavbarItem, "    a[flowbiteNavbarItem],    button[flowbiteNavbarItem]  ", ["flowbiteNavbarItem"], { "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, [{ directive: typeof flowbite_angular_button.BaseButton; inputs: { "color": "color"; }; outputs: {}; }, { directive: typeof i2.NgpButton; inputs: { "disabled": "disabled"; }; outputs: {}; }, { directive: typeof i3.NgpFocus; inputs: { "ngpFocusDisabled": "focusDisabled"; }; outputs: { "ngpFocus": "ngpFocus"; }; }]>;
}

declare const FlowbiteNavbarItemStateToken: _angular_core.InjectionToken<NavbarItem>;
declare const provideFlowbiteNavbarItemState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteNavbarItemState: <U = {
    readonly config: flowbite_angular_navbar.FlowbiteNavbarItemConfig;
    readonly navbarState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: /*elided*/ any;
        readonly fixed: /*elided*/ any;
        readonly open: /*elided*/ any;
        readonly color: /*elided*/ any;
        readonly customTheme: /*elided*/ any;
        readonly theme: /*elided*/ any;
        readonly state: /*elided*/ any;
        toggle: /*elided*/ any;
    }>>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            focus?: string | undefined;
            disabled?: string | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
                xl?: string | undefined;
            } | undefined;
            pill?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
            colorOutline?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<NavbarItem>;
    onClick: () => void;
    toggleNavbar: () => void;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteNavbarItemState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

interface FlowbiteNavbarContentTheme {
    host: FlowbiteNavbarContentHostTheme;
    container: FlowbiteNavbarContentContainerTheme;
}
interface FlowbiteNavbarContentHostTheme {
    base: string;
    transition: string;
    fixed: FlowbiteBoolean;
    open: FlowbiteBoolean;
}
interface FlowbiteNavbarContentContainerTheme {
    base: string;
    transition: string;
    color: FlowbiteNavbarColors;
}
declare const flowbiteNavbarContentTheme: FlowbiteNavbarContentTheme;

interface FlowbiteNavbarContentConfig {
    /**
     * The default theme of navbar-content
     */
    baseTheme: FlowbiteNavbarContentTheme;
    /**
     * The custom theme of navbar-content
     */
    customTheme: DeepPartial<FlowbiteNavbarContentTheme>;
}
declare const defaultFlowbiteNavbarContentConfig: FlowbiteNavbarContentConfig;
declare const FlowbiteNavbarContentConfigToken: InjectionToken<FlowbiteNavbarContentConfig>;
/**
 * Provide the default NavbarContent configuration
 * @param config The NavbarContent configuration
 * @returns The provider
 */
declare const provideFlowbiteNavbarContentConfig: (config: Partial<FlowbiteNavbarContentConfig>) => Provider[];
/**
 * Inject the NavbarContent configuration
 * @see {@link defaultFlowbiteNavbarContentConfig}
 * @returns The configuration
 */
declare const injectFlowbiteNavbarContentConfig: () => FlowbiteNavbarContentConfig;

declare class NavbarContent {
    protected readonly config: FlowbiteNavbarContentConfig;
    protected readonly navbarState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: flowbite_angular_navbar.FlowbiteNavbarConfig;
        readonly fixed: _angular_core.InputSignalWithTransform<boolean, _angular_cdk_coercion.BooleanInput>;
        readonly open: _angular_core.InputSignalWithTransform<boolean, _angular_cdk_coercion.BooleanInput>;
        readonly color: _angular_core.InputSignal<keyof flowbite_angular_navbar.FlowbiteNavbarColors>;
        readonly customTheme: _angular_core.InputSignal<{
            host?: {
                base?: string | undefined;
                transition?: string | undefined;
                fixed?: {
                    off?: string | undefined;
                    on?: string | undefined;
                } | undefined;
                color?: {
                    [x: string]: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    default?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    info?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    failure?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    success?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    warning?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    primary?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                } | undefined;
            } | undefined;
            container?: {
                base?: string | undefined;
                transition?: string | undefined;
            } | undefined;
        }>;
        readonly theme: _angular_core.Signal<{
            host: {
                root: string;
            };
            container: {
                root: string;
            };
        }>;
        readonly state: ng_primitives_state.CreatedState<flowbite_angular_navbar.Navbar>;
        toggle: (newState?: boolean) => void;
    }>>;
    /**
     * @see {@link injectFlowbiteNavbarContentConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            fixed?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
            open?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
        } | undefined;
        container?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
        container: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<NavbarContent>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<NavbarContent, never>;
    static ɵcmp: _angular_core.ɵɵComponentDeclaration<NavbarContent, "    div[flowbiteNavbarContent]  ", ["flowbiteNavbarContent"], { "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, ["*"], true, never>;
}

declare const FlowbiteNavbarContentStateToken: _angular_core.InjectionToken<NavbarContent>;
declare const provideFlowbiteNavbarContentState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteNavbarContentState: <U = {
    readonly config: flowbite_angular_navbar.FlowbiteNavbarContentConfig;
    readonly navbarState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: /*elided*/ any;
        readonly fixed: /*elided*/ any;
        readonly open: /*elided*/ any;
        readonly color: /*elided*/ any;
        readonly customTheme: /*elided*/ any;
        readonly theme: /*elided*/ any;
        readonly state: /*elided*/ any;
        toggle: /*elided*/ any;
    }>>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            fixed?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
            open?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
        } | undefined;
        container?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
        container: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<NavbarContent>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteNavbarContentState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

interface FlowbiteNavbarToggleTheme {
    host: FlowbiteNavbarToggleHostTheme;
}
interface FlowbiteNavbarToggleHostTheme {
    base: string;
    transition: string;
    focus: string;
    disabled: string;
    size: FlowbiteBaseButtonSizes;
    pill: FlowbiteBoolean;
    color: FlowbiteBaseButtonColors;
    colorOutline: FlowbiteBaseButtonColors;
}
declare const flowbiteNavbarToggleTheme: FlowbiteNavbarToggleTheme;

interface FlowbiteNavbarToggleConfig {
    /**
     * The default theme of navbar-toggle
     */
    baseTheme: FlowbiteNavbarToggleTheme;
    /**
     * The custom theme of navbar-toggle
     */
    customTheme: DeepPartial<FlowbiteNavbarToggleTheme>;
}
declare const defaultFlowbiteNavbarToggleConfig: FlowbiteNavbarToggleConfig;
declare const FlowbiteNavbarToggleConfigToken: InjectionToken<FlowbiteNavbarToggleConfig>;
/**
 * Provide the default NavbarToggle configuration
 * @param config The NavbarToggle configuration
 * @returns The provider
 */
declare const provideFlowbiteNavbarToggleConfig: (config: Partial<FlowbiteNavbarToggleConfig>) => Provider[];
/**
 * Inject the NavbarToggle configuration
 * @see {@link defaultFlowbiteNavbarToggleConfig}
 * @returns The configuration
 */
declare const injectFlowbiteNavbarToggleConfig: () => FlowbiteNavbarToggleConfig;

declare class NavbarToggle {
    protected readonly config: FlowbiteNavbarToggleConfig;
    protected readonly navbarState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: flowbite_angular_navbar.FlowbiteNavbarConfig;
        readonly fixed: _angular_core.InputSignalWithTransform<boolean, _angular_cdk_coercion.BooleanInput>;
        readonly open: _angular_core.InputSignalWithTransform<boolean, _angular_cdk_coercion.BooleanInput>;
        readonly color: _angular_core.InputSignal<keyof flowbite_angular_navbar.FlowbiteNavbarColors>;
        readonly customTheme: _angular_core.InputSignal<{
            host?: {
                base?: string | undefined;
                transition?: string | undefined;
                fixed?: {
                    off?: string | undefined;
                    on?: string | undefined;
                } | undefined;
                color?: {
                    [x: string]: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    default?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    info?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    failure?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    success?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    warning?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    primary?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                } | undefined;
            } | undefined;
            container?: {
                base?: string | undefined;
                transition?: string | undefined;
            } | undefined;
        }>;
        readonly theme: _angular_core.Signal<{
            host: {
                root: string;
            };
            container: {
                root: string;
            };
        }>;
        readonly state: ng_primitives_state.CreatedState<flowbite_angular_navbar.Navbar>;
        toggle: (newState?: boolean) => void;
    }>>;
    /**
     * @see {@link injectFlowbiteNavbarToggleConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            focus?: string | undefined;
            disabled?: string | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
                xl?: string | undefined;
            } | undefined;
            pill?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
            colorOutline?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<NavbarToggle>;
    /**
     * @internal
     */
    onClick(): void;
    /**
     * @internal
     */
    toggleNavbar(): void;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<NavbarToggle, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<NavbarToggle, "    button[flowbiteNavbarToggle]  ", ["flowbiteNavbarToggle"], { "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, [{ directive: typeof flowbite_angular_button.BaseButton; inputs: {}; outputs: {}; }]>;
}

declare const FlowbiteNavbarToggleStateToken: _angular_core.InjectionToken<NavbarToggle>;
declare const provideFlowbiteNavbarToggleState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteNavbarToggleState: <U = {
    readonly config: flowbite_angular_navbar.FlowbiteNavbarToggleConfig;
    readonly navbarState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: /*elided*/ any;
        readonly fixed: /*elided*/ any;
        readonly open: /*elided*/ any;
        readonly color: /*elided*/ any;
        readonly customTheme: /*elided*/ any;
        readonly theme: /*elided*/ any;
        readonly state: /*elided*/ any;
        toggle: /*elided*/ any;
    }>>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            focus?: string | undefined;
            disabled?: string | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
                xl?: string | undefined;
            } | undefined;
            pill?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
            colorOutline?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<NavbarToggle>;
    onClick: () => void;
    toggleNavbar: () => void;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteNavbarToggleState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

interface FlowbiteNavbarBrandTheme {
    host: FlowbiteNavbarBrandHostTheme;
}
interface FlowbiteNavbarBrandHostTheme {
    base: string;
    transition: string;
}
declare const flowbiteNavbarBrandTheme: FlowbiteNavbarBrandTheme;

interface FlowbiteNavbarBrandConfig {
    /**
     * The default theme of navbar-brand
     */
    baseTheme: FlowbiteNavbarBrandTheme;
    /**
     * The custom theme of navbar-brand
     */
    customTheme: DeepPartial<FlowbiteNavbarBrandTheme>;
}
declare const defaultFlowbiteNavbarBrandConfig: FlowbiteNavbarBrandConfig;
declare const FlowbiteNavbarBrandConfigToken: InjectionToken<FlowbiteNavbarBrandConfig>;
/**
 * Provide the default NavbarBrand configuration
 * @param config The NavbarBrand configuration
 * @returns The provider
 */
declare const provideFlowbiteNavbarBrandConfig: (config: Partial<FlowbiteNavbarBrandConfig>) => Provider[];
/**
 * Inject the NavbarBrand configuration
 * @see {@link defaultFlowbiteNavbarBrandConfig}
 * @returns The configuration
 */
declare const injectFlowbiteNavbarBrandConfig: () => FlowbiteNavbarBrandConfig;

declare class NavbarBrand {
    protected readonly config: FlowbiteNavbarBrandConfig;
    /**
     * @see {@link injectFlowbiteNavbarBrandConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    protected readonly state: ng_primitives_state.CreatedState<NavbarBrand>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<NavbarBrand, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<NavbarBrand, "    a[flowbiteNavbarBrand]  ", ["flowbiteNavbarBrand"], { "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, never>;
}

declare const FlowbiteNavbarBrandStateToken: _angular_core.InjectionToken<NavbarBrand>;
declare const provideFlowbiteNavbarBrandState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteNavbarBrandState: <U = {
    readonly config: flowbite_angular_navbar.FlowbiteNavbarBrandConfig;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<NavbarBrand>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteNavbarBrandState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

interface FlowbiteNavbarIconItemTheme {
    host: FlowbiteNavbarIconItemHostTheme;
}
interface FlowbiteNavbarIconItemHostTheme {
    base: string;
    transition: string;
    focus: string;
    disabled: string;
    size: FlowbiteBaseButtonSizes;
    pill: FlowbiteBoolean;
    color: FlowbiteBaseButtonColors;
    colorOutline: FlowbiteBaseButtonColors;
}
declare const flowbiteNavbarIconItemTheme: FlowbiteNavbarIconItemTheme;

interface FlowbiteNavbarIconItemConfig {
    /**
     * The default theme of NavbarIconItem
     */
    baseTheme: FlowbiteNavbarIconItemTheme;
    /**
     * The custom theme of NavbarIconItem
     */
    customTheme: DeepPartial<FlowbiteNavbarIconItemTheme>;
}
declare const defaultFlowbiteNavbarIconItemConfig: FlowbiteNavbarIconItemConfig;
declare const FlowbiteNavbarIconItemConfigToken: InjectionToken<FlowbiteNavbarIconItemConfig>;
/**
 * Provide the default NavbarIconItem configuration
 * @param config The NavbarIconItem configuration
 * @returns The provider
 */
declare const provideFlowbiteNavbarIconItemConfig: (config: Partial<FlowbiteNavbarIconItemConfig>) => Provider[];
/**
 * Inject the NavbarIconItem configuration
 * @see {@link defaultFlowbiteNavbarIconItemConfig}
 * @returns The configuration
 */
declare const injectFlowbiteNavbarIconItemConfig: () => FlowbiteNavbarIconItemConfig;

declare class NavbarIconItem {
    protected readonly baseButtonState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: flowbite_angular_button.FlowbiteBaseButtonConfig;
        readonly color: _angular_core.InputSignal<keyof flowbite_angular_button.FlowbiteBaseButtonColors>;
        readonly size: _angular_core.InputSignal<keyof flowbite_angular_button.FlowbiteBaseButtonSizes>;
        readonly pill: _angular_core.InputSignalWithTransform<boolean, unknown>;
        readonly outline: _angular_core.InputSignalWithTransform<boolean, unknown>;
        readonly state: ng_primitives_state.CreatedState<BaseButton>;
    }>>;
    protected readonly navbarState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: flowbite_angular_navbar.FlowbiteNavbarConfig;
        readonly fixed: _angular_core.InputSignalWithTransform<boolean, _angular_cdk_coercion.BooleanInput>;
        readonly open: _angular_core.InputSignalWithTransform<boolean, _angular_cdk_coercion.BooleanInput>;
        readonly color: _angular_core.InputSignal<keyof flowbite_angular_navbar.FlowbiteNavbarColors>;
        readonly customTheme: _angular_core.InputSignal<{
            host?: {
                base?: string | undefined;
                transition?: string | undefined;
                fixed?: {
                    off?: string | undefined;
                    on?: string | undefined;
                } | undefined;
                color?: {
                    [x: string]: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    default?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    info?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    failure?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    success?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    warning?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    primary?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                } | undefined;
            } | undefined;
            container?: {
                base?: string | undefined;
                transition?: string | undefined;
            } | undefined;
        }>;
        readonly theme: _angular_core.Signal<{
            host: {
                root: string;
            };
            container: {
                root: string;
            };
        }>;
        readonly state: ng_primitives_state.CreatedState<flowbite_angular_navbar.Navbar>;
        toggle: (newState?: boolean) => void;
    }>>;
    protected readonly config: FlowbiteNavbarIconItemConfig;
    /**
     * @see {@link injectFlowbiteNavbarIconItemConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            focus?: string | undefined;
            disabled?: string | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
                xl?: string | undefined;
            } | undefined;
            pill?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
            colorOutline?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<NavbarIconItem>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<NavbarIconItem, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<NavbarIconItem, "    button[flowbiteNavbarIconItem],    a[flowbiteNavbarIconItem],  ", ["flowbiteNavbarIconItem"], { "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, [{ directive: typeof flowbite_angular_button.BaseButton; inputs: { "color": "color"; }; outputs: {}; }, { directive: typeof i2.NgpButton; inputs: { "disabled": "disabled"; }; outputs: {}; }, { directive: typeof i3.NgpFocus; inputs: { "ngpFocusDisabled": "focusDisabled"; }; outputs: { "ngpFocus": "ngpFocus"; }; }]>;
}

declare const FlowbiteNavbarIconItemStateToken: _angular_core.InjectionToken<NavbarIconItem>;
declare const provideFlowbiteNavbarIconItemState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteNavbarIconItemState: <U = {
    readonly baseButtonState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: flowbite_angular_button.FlowbiteBaseButtonConfig;
        readonly color: _angular_core.InputSignal<keyof flowbite_angular_button.FlowbiteBaseButtonColors>;
        readonly size: _angular_core.InputSignal<keyof flowbite_angular_button.FlowbiteBaseButtonSizes>;
        readonly pill: _angular_core.InputSignalWithTransform<boolean, unknown>;
        readonly outline: _angular_core.InputSignalWithTransform<boolean, unknown>;
        readonly state: ng_primitives_state.CreatedState<flowbite_angular_button.BaseButton>;
    }>>;
    readonly navbarState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: /*elided*/ any;
        readonly fixed: /*elided*/ any;
        readonly open: /*elided*/ any;
        readonly color: /*elided*/ any;
        readonly customTheme: /*elided*/ any;
        readonly theme: /*elided*/ any;
        readonly state: /*elided*/ any;
        toggle: /*elided*/ any;
    }>>;
    readonly config: flowbite_angular_navbar.FlowbiteNavbarIconItemConfig;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            focus?: string | undefined;
            disabled?: string | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
                xl?: string | undefined;
            } | undefined;
            pill?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
            colorOutline?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<NavbarIconItem>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteNavbarIconItemState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

export { FlowbiteNavbarBrandConfigToken, FlowbiteNavbarBrandStateToken, FlowbiteNavbarConfigToken, FlowbiteNavbarContentConfigToken, FlowbiteNavbarContentStateToken, FlowbiteNavbarIconItemConfigToken, FlowbiteNavbarIconItemStateToken, FlowbiteNavbarItemConfigToken, FlowbiteNavbarItemStateToken, FlowbiteNavbarStateToken, FlowbiteNavbarToggleConfigToken, FlowbiteNavbarToggleStateToken, Navbar, NavbarBrand, NavbarContent, NavbarIconItem, NavbarItem, NavbarToggle, defaultFlowbiteNavbarBrandConfig, defaultFlowbiteNavbarConfig, defaultFlowbiteNavbarContentConfig, defaultFlowbiteNavbarIconItemConfig, defaultFlowbiteNavbarItemConfig, defaultFlowbiteNavbarToggleConfig, flowbiteNavbarBrandState, flowbiteNavbarBrandTheme, flowbiteNavbarContentState, flowbiteNavbarContentTheme, flowbiteNavbarIconItemState, flowbiteNavbarIconItemTheme, flowbiteNavbarItemState, flowbiteNavbarItemTheme, flowbiteNavbarState, flowbiteNavbarTheme, flowbiteNavbarToggleState, flowbiteNavbarToggleTheme, injectFlowbiteNavbarBrandConfig, injectFlowbiteNavbarBrandState, injectFlowbiteNavbarConfig, injectFlowbiteNavbarContentConfig, injectFlowbiteNavbarContentState, injectFlowbiteNavbarIconItemConfig, injectFlowbiteNavbarIconItemState, injectFlowbiteNavbarItemConfig, injectFlowbiteNavbarItemState, injectFlowbiteNavbarState, injectFlowbiteNavbarToggleConfig, injectFlowbiteNavbarToggleState, provideFlowbiteNavbarBrandConfig, provideFlowbiteNavbarBrandState, provideFlowbiteNavbarConfig, provideFlowbiteNavbarContentConfig, provideFlowbiteNavbarContentState, provideFlowbiteNavbarIconItemConfig, provideFlowbiteNavbarIconItemState, provideFlowbiteNavbarItemConfig, provideFlowbiteNavbarItemState, provideFlowbiteNavbarState, provideFlowbiteNavbarToggleConfig, provideFlowbiteNavbarToggleState };
export type { FlowbiteNavbarBrandConfig, FlowbiteNavbarBrandHostTheme, FlowbiteNavbarBrandTheme, FlowbiteNavbarColors, FlowbiteNavbarConfig, FlowbiteNavbarContainerTheme, FlowbiteNavbarContentConfig, FlowbiteNavbarContentContainerTheme, FlowbiteNavbarContentHostTheme, FlowbiteNavbarContentTheme, FlowbiteNavbarHostTheme, FlowbiteNavbarIconItemConfig, FlowbiteNavbarIconItemHostTheme, FlowbiteNavbarIconItemTheme, FlowbiteNavbarItemConfig, FlowbiteNavbarItemHostTheme, FlowbiteNavbarItemTheme, FlowbiteNavbarTheme, FlowbiteNavbarToggleConfig, FlowbiteNavbarToggleHostTheme, FlowbiteNavbarToggleTheme };
