import { ColorToTheme, FlowbiteSizes, DeepPartial } from 'flowbite-angular';
import { FlowbiteBaseButtonColors } from 'flowbite-angular/button';
import * as _angular_core from '@angular/core';
import { InjectionToken, Provider } from '@angular/core';
import * as ng_primitives_state from 'ng-primitives/state';
import * as i1 from 'ng-primitives/pagination';
import { NgpPagination } from 'ng-primitives/pagination';
import * as flowbite_angular_pagination from 'flowbite-angular/pagination';
import * as _angular_cdk_coercion from '@angular/cdk/coercion';
import { BooleanInput } from '@angular/cdk/coercion';
import * as i2 from 'ng-primitives/interactions';

interface FlowbitePaginationSizes extends Pick<FlowbiteSizes, 'xs' | 'sm' | 'md' | 'lg' | 'xl'> {
    [key: string]: string;
}
interface FlowbitePaginationColors extends FlowbiteBaseButtonColors {
    [key: string]: ColorToTheme;
}
interface FlowbitePaginationTheme {
    host: FlowbitePaginationHostTheme;
    container: FlowbitePaginationContainerTheme;
}
interface FlowbitePaginationHostTheme {
    base: string;
    transition: string;
}
interface FlowbitePaginationContainerTheme {
    base: string;
    transition: string;
}
declare const flowbitePaginationTheme: FlowbitePaginationTheme;

interface FlowbitePaginationConfig {
    /**
     * The default theme of pagination
     */
    baseTheme: FlowbitePaginationTheme;
    /**
     * The default tabs number of pagination
     */
    tabs: number;
    /**
     * The default color of pagination
     */
    color: keyof FlowbitePaginationColors;
    /**
     * The default size of pagination
     */
    size: keyof FlowbitePaginationSizes;
    /**
     * The custom theme of pagination
     */
    customTheme: DeepPartial<FlowbitePaginationTheme>;
}
declare const defaultFlowbitePaginationConfig: FlowbitePaginationConfig;
declare const FlowbitePaginationConfigToken: InjectionToken<FlowbitePaginationConfig>;
/**
 * Provide the default Pagination configuration
 * @param config The Pagination configuration
 * @returns The provider
 */
declare const provideFlowbitePaginationConfig: (config: Partial<FlowbitePaginationConfig>) => Provider[];
/**
 * Inject the Pagination configuration
 * @see {@link defaultFlowbitePaginationConfig}
 * @returns The configuration
 */
declare const injectFlowbitePaginationConfig: () => FlowbitePaginationConfig;

declare class Pagination {
    protected readonly paginationState: _angular_core.Signal<ng_primitives_state.State<NgpPagination>>;
    protected readonly config: FlowbitePaginationConfig;
    /**
     * Value of how many page tabs to display
     */
    readonly visiblePagesCount: _angular_core.Signal<number>;
    /**
     * Value of the first visible page
     */
    readonly firstPageToShow: _angular_core.Signal<number>;
    /**
     * Array of the visible page tabs
     */
    readonly visiblePages: _angular_core.Signal<number[]>;
    protected readonly pages: _angular_core.Signal<number[]>;
    /**
     * @see {@link injectFlowbitePaginationConfig}
     */
    readonly tabs: _angular_core.InputSignal<number>;
    /**
     * @see {@link injectFlowbitePaginationConfig}
     */
    readonly color: _angular_core.InputSignal<keyof FlowbitePaginationColors>;
    /**
     * @see {@link injectFlowbitePaginationConfig}
     */
    readonly size: _angular_core.InputSignal<keyof FlowbitePaginationSizes>;
    /**
     * @see {@link injectFlowbitePaginationConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
        } | undefined;
        container?: {
            base?: string | undefined;
            transition?: string | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
        container: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<Pagination>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<Pagination, never>;
    static ɵcmp: _angular_core.ɵɵComponentDeclaration<Pagination, "    nav[flowbitePagination]  ", ["flowbitePagination"], { "tabs": { "alias": "tabs"; "required": false; "isSignal": true; }; "color": { "alias": "color"; "required": false; "isSignal": true; }; "size": { "alias": "size"; "required": false; "isSignal": true; }; "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, [{ directive: typeof i1.NgpPagination; inputs: { "ngpPaginationPage": "page"; "ngpPaginationPageCount": "pageCount"; "ngpPaginationDisabled": "disabled"; }; outputs: { "ngpPaginationPageChange": "pageChange"; }; }]>;
}

declare const FlowbitePaginationStateToken: _angular_core.InjectionToken<Pagination>;
declare const provideFlowbitePaginationState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbitePaginationState: <U = {
    readonly paginationState: _angular_core.Signal<ng_primitives_state.State<i1.NgpPagination>>;
    readonly config: flowbite_angular_pagination.FlowbitePaginationConfig;
    readonly visiblePagesCount: _angular_core.Signal<number>;
    readonly firstPageToShow: _angular_core.Signal<number>;
    readonly visiblePages: _angular_core.Signal<number[]>;
    readonly pages: _angular_core.Signal<number[]>;
    readonly tabs: _angular_core.InputSignal<number>;
    readonly color: _angular_core.InputSignal<keyof flowbite_angular_pagination.FlowbitePaginationColors>;
    readonly size: _angular_core.InputSignal<keyof flowbite_angular_pagination.FlowbitePaginationSizes>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
        } | undefined;
        container?: {
            base?: string | undefined;
            transition?: string | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
        container: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<Pagination>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbitePaginationState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

interface FlowbitePaginationFirstSizes extends FlowbitePaginationSizes {
    [key: string]: string;
}
interface FlowbitePaginationFirstColors extends FlowbitePaginationColors {
    [key: string]: ColorToTheme;
}
interface FlowbitePaginationFirstTheme {
    host: FlowbitePaginationFirstHostTheme;
}
interface FlowbitePaginationFirstHostTheme {
    base: string;
    transition: string;
    focus: string;
    disabled: string;
    size: FlowbitePaginationFirstSizes;
    colorOutline: FlowbitePaginationFirstColors;
}
declare const flowbitePaginationFirstTheme: FlowbitePaginationFirstTheme;

interface FlowbitePaginationFirstConfig {
    /**
     * The default theme of PaginationFirst
     */
    baseTheme: FlowbitePaginationFirstTheme;
    /**
     * The default color of button.
     */
    color: keyof FlowbitePaginationFirstColors;
    /**
     * The default size of button.
     */
    size: keyof FlowbitePaginationFirstSizes;
    /**
     * Whether the button is outline.
     */
    outline: boolean;
    /**
     * The custom theme of PaginationFirst
     */
    customTheme: DeepPartial<FlowbitePaginationFirstTheme>;
}
declare const defaultFlowbitePaginationFirstConfig: FlowbitePaginationFirstConfig;
declare const FlowbitePaginationFirstConfigToken: InjectionToken<FlowbitePaginationFirstConfig>;
/**
 * Provide the default PaginationFirst configuration
 * @param config The PaginationFirst configuration
 * @returns The provider
 */
declare const provideFlowbitePaginationFirstConfig: (config: Partial<FlowbitePaginationFirstConfig>) => Provider[];
/**
 * Inject the PaginationFirst configuration
 * @see {@link defaultFlowbitePaginationFirstConfig}
 * @returns The configuration
 */
declare const injectFlowbitePaginationFirstConfig: () => FlowbitePaginationFirstConfig;

declare class PaginationFirst {
    protected readonly config: FlowbitePaginationFirstConfig;
    /**
     * @see {@link injectFlowbitePaginationFirstConfig}
     */
    readonly color: _angular_core.InputSignal<keyof FlowbitePaginationFirstColors>;
    /**
     * @see {@link injectFlowbitePaginationFirstConfig}
     */
    readonly size: _angular_core.InputSignal<keyof FlowbitePaginationFirstSizes>;
    /**
     * @see {@link injectFlowbitePaginationFirstConfig}
     */
    readonly outline: _angular_core.InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * @see {@link injectFlowbitePaginationFirstConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            focus?: string | undefined;
            disabled?: string | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
                xl?: string | undefined;
            } | undefined;
            colorOutline?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<PaginationFirst>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<PaginationFirst, never>;
    static ɵcmp: _angular_core.ɵɵComponentDeclaration<PaginationFirst, "    button[flowbitePaginationFirst]  ", ["flowbitePaginationFirst"], { "color": { "alias": "color"; "required": false; "isSignal": true; }; "size": { "alias": "size"; "required": false; "isSignal": true; }; "outline": { "alias": "outline"; "required": false; "isSignal": true; }; "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, [{ directive: typeof i1.NgpPaginationFirst; inputs: { "ngpPaginationFirstDisabled": "disabled"; }; outputs: {}; }, { directive: typeof i2.NgpFocus; inputs: {}; outputs: {}; }]>;
}

declare const FlowbitePaginationFirstStateToken: _angular_core.InjectionToken<PaginationFirst>;
declare const provideFlowbitePaginationFirstState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbitePaginationFirstState: <U = {
    readonly config: flowbite_angular_pagination.FlowbitePaginationFirstConfig;
    readonly color: _angular_core.InputSignal<keyof flowbite_angular_pagination.FlowbitePaginationFirstColors>;
    readonly size: _angular_core.InputSignal<keyof flowbite_angular_pagination.FlowbitePaginationFirstSizes>;
    readonly outline: _angular_core.InputSignalWithTransform<boolean, _angular_cdk_coercion.BooleanInput>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            focus?: string | undefined;
            disabled?: string | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
                xl?: string | undefined;
            } | undefined;
            colorOutline?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<PaginationFirst>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbitePaginationFirstState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

interface FlowbitePaginationPreviousSizes extends FlowbitePaginationSizes {
    [key: string]: string;
}
interface FlowbitePaginationPreviousColors extends FlowbitePaginationColors {
    [key: string]: ColorToTheme;
}
interface FlowbitePaginationPreviousTheme {
    host: FlowbitePaginationPreviousHostTheme;
}
interface FlowbitePaginationPreviousHostTheme {
    base: string;
    transition: string;
    focus: string;
    disabled: string;
    size: FlowbitePaginationPreviousSizes;
    colorOutline: FlowbitePaginationPreviousColors;
}
declare const flowbitePaginationPreviousTheme: FlowbitePaginationPreviousTheme;

interface FlowbitePaginationPreviousConfig {
    /**
     * The default theme of PaginationPrevious
     */
    baseTheme: FlowbitePaginationPreviousTheme;
    /**
     * The default color of button.
     */
    color: keyof FlowbitePaginationPreviousColors;
    /**
     * The default size of button.
     */
    size: keyof FlowbitePaginationPreviousSizes;
    /**
     * Whether the button is outline.
     */
    outline: boolean;
    /**
     * The custom theme of PaginationPrevious
     */
    customTheme: DeepPartial<FlowbitePaginationPreviousTheme>;
}
declare const defaultFlowbitePaginationPreviousConfig: FlowbitePaginationPreviousConfig;
declare const FlowbitePaginationPreviousConfigToken: InjectionToken<FlowbitePaginationPreviousConfig>;
/**
 * Provide the default PaginationPrevious configuration
 * @param config The PaginationPrevious configuration
 * @returns The provider
 */
declare const provideFlowbitePaginationPreviousConfig: (config: Partial<FlowbitePaginationPreviousConfig>) => Provider[];
/**
 * Inject the PaginationPrevious configuration
 * @see {@link defaultFlowbitePaginationPreviousConfig}
 * @returns The configuration
 */
declare const injectFlowbitePaginationPreviousConfig: () => FlowbitePaginationPreviousConfig;

declare class PaginationPrevious {
    protected readonly config: FlowbitePaginationPreviousConfig;
    /**
     * @see {@link injectFlowbitePaginationPreviousConfig}
     */
    readonly color: _angular_core.InputSignal<keyof FlowbitePaginationPreviousColors>;
    /**
     * @see {@link injectFlowbitePaginationPreviousConfig}
     */
    readonly size: _angular_core.InputSignal<keyof FlowbitePaginationPreviousSizes>;
    /**
     * @see {@link injectFlowbitePaginationPreviousConfig}
     */
    readonly outline: _angular_core.InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * @see {@link injectFlowbitePaginationPreviousConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            focus?: string | undefined;
            disabled?: string | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
                xl?: string | undefined;
            } | undefined;
            colorOutline?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<PaginationPrevious>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<PaginationPrevious, never>;
    static ɵcmp: _angular_core.ɵɵComponentDeclaration<PaginationPrevious, "    button[flowbitePaginationPrevious]  ", ["flowbitePaginationPrevious"], { "color": { "alias": "color"; "required": false; "isSignal": true; }; "size": { "alias": "size"; "required": false; "isSignal": true; }; "outline": { "alias": "outline"; "required": false; "isSignal": true; }; "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, [{ directive: typeof i1.NgpPaginationPrevious; inputs: { "ngpPaginationPreviousDisabled": "disabled"; }; outputs: {}; }, { directive: typeof i2.NgpFocus; inputs: {}; outputs: {}; }]>;
}

declare const FlowbitePaginationPreviousStateToken: _angular_core.InjectionToken<PaginationPrevious>;
declare const provideFlowbitePaginationPreviousState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbitePaginationPreviousState: <U = {
    readonly config: flowbite_angular_pagination.FlowbitePaginationPreviousConfig;
    readonly color: _angular_core.InputSignal<keyof flowbite_angular_pagination.FlowbitePaginationPreviousColors>;
    readonly size: _angular_core.InputSignal<keyof flowbite_angular_pagination.FlowbitePaginationPreviousSizes>;
    readonly outline: _angular_core.InputSignalWithTransform<boolean, _angular_cdk_coercion.BooleanInput>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            focus?: string | undefined;
            disabled?: string | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
                xl?: string | undefined;
            } | undefined;
            colorOutline?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<PaginationPrevious>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbitePaginationPreviousState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

interface FlowbitePaginationNextSizes extends FlowbitePaginationSizes {
    [key: string]: string;
}
interface FlowbitePaginationNextColors extends FlowbitePaginationColors {
    [key: string]: ColorToTheme;
}
interface FlowbitePaginationNextTheme {
    host: FlowbitePaginationNextHostTheme;
}
interface FlowbitePaginationNextHostTheme {
    base: string;
    transition: string;
    focus: string;
    disabled: string;
    size: FlowbitePaginationNextSizes;
    colorOutline: FlowbitePaginationNextColors;
}
declare const flowbitePaginationNextTheme: FlowbitePaginationNextTheme;

interface FlowbitePaginationNextConfig {
    /**
     * The default theme of PaginationNext
     */
    baseTheme: FlowbitePaginationNextTheme;
    /**
     * The default color of button.
     */
    color: keyof FlowbitePaginationNextColors;
    /**
     * The default size of button.
     */
    size: keyof FlowbitePaginationNextSizes;
    /**
     * Whether the button is outline.
     */
    outline: boolean;
    /**
     * The custom theme of PaginationNext
     */
    customTheme: DeepPartial<FlowbitePaginationNextTheme>;
}
declare const defaultFlowbitePaginationNextConfig: FlowbitePaginationNextConfig;
declare const FlowbitePaginationNextConfigToken: InjectionToken<FlowbitePaginationNextConfig>;
/**
 * Provide the default PaginationNext configuration
 * @param config The PaginationNext configuration
 * @returns The provider
 */
declare const provideFlowbitePaginationNextConfig: (config: Partial<FlowbitePaginationNextConfig>) => Provider[];
/**
 * Inject the PaginationNext configuration
 * @see {@link defaultFlowbitePaginationNextConfig}
 * @returns The configuration
 */
declare const injectFlowbitePaginationNextConfig: () => FlowbitePaginationNextConfig;

declare class PaginationNext {
    protected readonly config: FlowbitePaginationNextConfig;
    /**
     * @see {@link injectFlowbitePaginationNextConfig}
     */
    readonly color: _angular_core.InputSignal<keyof FlowbitePaginationNextColors>;
    /**
     * @see {@link injectFlowbitePaginationNextConfig}
     */
    readonly size: _angular_core.InputSignal<keyof FlowbitePaginationNextSizes>;
    /**
     * @see {@link injectFlowbitePaginationNextConfig}
     */
    readonly outline: _angular_core.InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * @see {@link injectFlowbitePaginationFirstConfig}
     */
    /**
     * @see {@link injectFlowbitePaginationNextConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            focus?: string | undefined;
            disabled?: string | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
                xl?: string | undefined;
            } | undefined;
            colorOutline?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<PaginationNext>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<PaginationNext, never>;
    static ɵcmp: _angular_core.ɵɵComponentDeclaration<PaginationNext, "    button[flowbitePaginationNext]  ", ["flowbitePaginationNext"], { "color": { "alias": "color"; "required": false; "isSignal": true; }; "size": { "alias": "size"; "required": false; "isSignal": true; }; "outline": { "alias": "outline"; "required": false; "isSignal": true; }; "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, [{ directive: typeof i1.NgpPaginationNext; inputs: { "ngpPaginationNextDisabled": "disabled"; }; outputs: {}; }, { directive: typeof i2.NgpFocus; inputs: {}; outputs: {}; }]>;
}

declare const FlowbitePaginationNextStateToken: _angular_core.InjectionToken<PaginationNext>;
declare const provideFlowbitePaginationNextState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbitePaginationNextState: <U = {
    readonly config: flowbite_angular_pagination.FlowbitePaginationNextConfig;
    readonly color: _angular_core.InputSignal<keyof flowbite_angular_pagination.FlowbitePaginationNextColors>;
    readonly size: _angular_core.InputSignal<keyof flowbite_angular_pagination.FlowbitePaginationNextSizes>;
    readonly outline: _angular_core.InputSignalWithTransform<boolean, _angular_cdk_coercion.BooleanInput>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            focus?: string | undefined;
            disabled?: string | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
                xl?: string | undefined;
            } | undefined;
            colorOutline?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<PaginationNext>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbitePaginationNextState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

interface FlowbitePaginationLastSizes extends FlowbitePaginationSizes {
    [key: string]: string;
}
interface FlowbitePaginationLastColors extends FlowbitePaginationColors {
    [key: string]: ColorToTheme;
}
interface FlowbitePaginationLastTheme {
    host: FlowbitePaginationLastHostTheme;
}
interface FlowbitePaginationLastHostTheme {
    base: string;
    transition: string;
    focus: string;
    disabled: string;
    size: FlowbitePaginationLastSizes;
    colorOutline: FlowbitePaginationLastColors;
}
declare const flowbitePaginationLastTheme: FlowbitePaginationLastTheme;

interface FlowbitePaginationLastConfig {
    /**
     * The default theme of PaginationLast
     */
    baseTheme: FlowbitePaginationLastTheme;
    /**
     * The default color of button.
     */
    color: keyof FlowbitePaginationLastColors;
    /**
     * The default size of button.
     */
    size: keyof FlowbitePaginationLastSizes;
    /**
     * Whether the button is outline.
     */
    outline: boolean;
    /**
     * The custom theme of PaginationLast
     */
    customTheme: DeepPartial<FlowbitePaginationLastTheme>;
}
declare const defaultFlowbitePaginationLastConfig: FlowbitePaginationLastConfig;
declare const FlowbitePaginationLastConfigToken: InjectionToken<FlowbitePaginationLastConfig>;
/**
 * Provide the default PaginationLast configuration
 * @param config The PaginationLast configuration
 * @returns The provider
 */
declare const provideFlowbitePaginationLastConfig: (config: Partial<FlowbitePaginationLastConfig>) => Provider[];
/**
 * Inject the PaginationLast configuration
 * @see {@link defaultFlowbitePaginationLastConfig}
 * @returns The configuration
 */
declare const injectFlowbitePaginationLastConfig: () => FlowbitePaginationLastConfig;

declare class PaginationLast {
    protected readonly config: FlowbitePaginationLastConfig;
    /**
     * @see {@link injectFlowbitePaginationLastConfig}
     */
    readonly color: _angular_core.InputSignal<keyof FlowbitePaginationLastColors>;
    /**
     * @see {@link injectFlowbitePaginationLastConfig}
     */
    readonly size: _angular_core.InputSignal<keyof FlowbitePaginationLastSizes>;
    /**
     * @see {@link injectFlowbitePaginationLastConfig}
     */
    readonly outline: _angular_core.InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * @see {@link injectFlowbitePaginationLastConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            focus?: string | undefined;
            disabled?: string | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
                xl?: string | undefined;
            } | undefined;
            colorOutline?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<PaginationLast>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<PaginationLast, never>;
    static ɵcmp: _angular_core.ɵɵComponentDeclaration<PaginationLast, "    button[flowbitePaginationLast]  ", ["flowbitePaginationLast"], { "color": { "alias": "color"; "required": false; "isSignal": true; }; "size": { "alias": "size"; "required": false; "isSignal": true; }; "outline": { "alias": "outline"; "required": false; "isSignal": true; }; "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, [{ directive: typeof i1.NgpPaginationLast; inputs: { "ngpPaginationLastDisabled": "disabled"; }; outputs: {}; }, { directive: typeof i2.NgpFocus; inputs: {}; outputs: {}; }]>;
}

declare const FlowbitePaginationLastStateToken: _angular_core.InjectionToken<PaginationLast>;
declare const provideFlowbitePaginationLastState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbitePaginationLastState: <U = {
    readonly config: flowbite_angular_pagination.FlowbitePaginationLastConfig;
    readonly color: _angular_core.InputSignal<keyof flowbite_angular_pagination.FlowbitePaginationLastColors>;
    readonly size: _angular_core.InputSignal<keyof flowbite_angular_pagination.FlowbitePaginationLastSizes>;
    readonly outline: _angular_core.InputSignalWithTransform<boolean, _angular_cdk_coercion.BooleanInput>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            focus?: string | undefined;
            disabled?: string | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
                xl?: string | undefined;
            } | undefined;
            colorOutline?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<PaginationLast>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbitePaginationLastState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

interface FlowbitePaginationButtonSizes extends FlowbitePaginationSizes {
    [key: string]: string;
}
interface FlowbitePaginationButtonColors extends FlowbitePaginationColors {
    [key: string]: ColorToTheme;
}
interface FlowbitePaginationButtonTheme {
    host: FlowbitePaginationButtonHostTheme;
}
interface FlowbitePaginationButtonHostTheme {
    base: string;
    transition: string;
    focus: string;
    disabled: string;
    size: FlowbitePaginationButtonSizes;
    colorOutline: FlowbitePaginationButtonColors;
}
declare const flowbitePaginationButtonTheme: FlowbitePaginationButtonTheme;

interface FlowbitePaginationButtonConfig {
    /**
     * The default theme of PaginationButton
     */
    baseTheme: FlowbitePaginationButtonTheme;
    /**
     * The default color of button.
     */
    color: keyof FlowbitePaginationButtonColors;
    /**
     * The default size of button.
     */
    size: keyof FlowbitePaginationButtonSizes;
    /**
     * Whether the button is outline.
     */
    outline: boolean;
    /**
     * The custom theme of PaginationButton
     */
    customTheme: DeepPartial<FlowbitePaginationButtonTheme>;
}
declare const defaultFlowbitePaginationButtonConfig: FlowbitePaginationButtonConfig;
declare const FlowbitePaginationButtonConfigToken: InjectionToken<FlowbitePaginationButtonConfig>;
/**
 * Provide the default PaginationButton configuration
 * @param config The PaginationButton configuration
 * @returns The provider
 */
declare const provideFlowbitePaginationButtonConfig: (config: Partial<FlowbitePaginationButtonConfig>) => Provider[];
/**
 * Inject the PaginationButton configuration
 * @see {@link defaultFlowbitePaginationButtonConfig}
 * @returns The configuration
 */
declare const injectFlowbitePaginationButtonConfig: () => FlowbitePaginationButtonConfig;

declare class PaginationButton {
    protected readonly config: FlowbitePaginationButtonConfig;
    /**
     * @see {@link injectFlowbitePaginationFirstConfig}
     */
    readonly color: _angular_core.InputSignal<keyof FlowbitePaginationButtonColors>;
    /**
     * @see {@link injectFlowbitePaginationFirstConfig}
     */
    readonly size: _angular_core.InputSignal<keyof FlowbitePaginationButtonSizes>;
    /**
     * @see {@link injectFlowbitePaginationFirstConfig}
     */
    readonly outline: _angular_core.InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * @see {@link injectFlowbitePaginationButtonConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            focus?: string | undefined;
            disabled?: string | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
                xl?: string | undefined;
            } | undefined;
            colorOutline?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<PaginationButton>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<PaginationButton, never>;
    static ɵcmp: _angular_core.ɵɵComponentDeclaration<PaginationButton, "    button[flowbitePaginationButton]  ", ["flowbitePaginationButton"], { "color": { "alias": "color"; "required": false; "isSignal": true; }; "size": { "alias": "size"; "required": false; "isSignal": true; }; "outline": { "alias": "outline"; "required": false; "isSignal": true; }; "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, ["*"], true, [{ directive: typeof i1.NgpPaginationButton; inputs: { "ngpPaginationButtonDisabled": "disabled"; "ngpPaginationButtonPage": "page"; }; outputs: {}; }, { directive: typeof i2.NgpFocus; inputs: {}; outputs: {}; }]>;
}

declare const FlowbitePaginationButtonStateToken: _angular_core.InjectionToken<PaginationButton>;
declare const provideFlowbitePaginationButtonState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbitePaginationButtonState: <U = {
    readonly config: flowbite_angular_pagination.FlowbitePaginationButtonConfig;
    readonly color: _angular_core.InputSignal<keyof flowbite_angular_pagination.FlowbitePaginationButtonColors>;
    readonly size: _angular_core.InputSignal<keyof flowbite_angular_pagination.FlowbitePaginationButtonSizes>;
    readonly outline: _angular_core.InputSignalWithTransform<boolean, _angular_cdk_coercion.BooleanInput>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            focus?: string | undefined;
            disabled?: string | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
                xl?: string | undefined;
            } | undefined;
            colorOutline?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<PaginationButton>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbitePaginationButtonState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

export { FlowbitePaginationButtonConfigToken, FlowbitePaginationButtonStateToken, FlowbitePaginationConfigToken, FlowbitePaginationFirstConfigToken, FlowbitePaginationFirstStateToken, FlowbitePaginationLastConfigToken, FlowbitePaginationLastStateToken, FlowbitePaginationNextConfigToken, FlowbitePaginationNextStateToken, FlowbitePaginationPreviousConfigToken, FlowbitePaginationPreviousStateToken, FlowbitePaginationStateToken, Pagination, PaginationButton, PaginationFirst, PaginationLast, PaginationNext, PaginationPrevious, defaultFlowbitePaginationButtonConfig, defaultFlowbitePaginationConfig, defaultFlowbitePaginationFirstConfig, defaultFlowbitePaginationLastConfig, defaultFlowbitePaginationNextConfig, defaultFlowbitePaginationPreviousConfig, flowbitePaginationButtonState, flowbitePaginationButtonTheme, flowbitePaginationFirstState, flowbitePaginationFirstTheme, flowbitePaginationLastState, flowbitePaginationLastTheme, flowbitePaginationNextState, flowbitePaginationNextTheme, flowbitePaginationPreviousState, flowbitePaginationPreviousTheme, flowbitePaginationState, flowbitePaginationTheme, injectFlowbitePaginationButtonConfig, injectFlowbitePaginationButtonState, injectFlowbitePaginationConfig, injectFlowbitePaginationFirstConfig, injectFlowbitePaginationFirstState, injectFlowbitePaginationLastConfig, injectFlowbitePaginationLastState, injectFlowbitePaginationNextConfig, injectFlowbitePaginationNextState, injectFlowbitePaginationPreviousConfig, injectFlowbitePaginationPreviousState, injectFlowbitePaginationState, provideFlowbitePaginationButtonConfig, provideFlowbitePaginationButtonState, provideFlowbitePaginationConfig, provideFlowbitePaginationFirstConfig, provideFlowbitePaginationFirstState, provideFlowbitePaginationLastConfig, provideFlowbitePaginationLastState, provideFlowbitePaginationNextConfig, provideFlowbitePaginationNextState, provideFlowbitePaginationPreviousConfig, provideFlowbitePaginationPreviousState, provideFlowbitePaginationState };
export type { FlowbitePaginationButtonColors, FlowbitePaginationButtonConfig, FlowbitePaginationButtonHostTheme, FlowbitePaginationButtonSizes, FlowbitePaginationButtonTheme, FlowbitePaginationColors, FlowbitePaginationConfig, FlowbitePaginationContainerTheme, FlowbitePaginationFirstColors, FlowbitePaginationFirstConfig, FlowbitePaginationFirstHostTheme, FlowbitePaginationFirstSizes, FlowbitePaginationFirstTheme, FlowbitePaginationHostTheme, FlowbitePaginationLastColors, FlowbitePaginationLastConfig, FlowbitePaginationLastHostTheme, FlowbitePaginationLastSizes, FlowbitePaginationLastTheme, FlowbitePaginationNextColors, FlowbitePaginationNextConfig, FlowbitePaginationNextHostTheme, FlowbitePaginationNextSizes, FlowbitePaginationNextTheme, FlowbitePaginationPreviousColors, FlowbitePaginationPreviousConfig, FlowbitePaginationPreviousHostTheme, FlowbitePaginationPreviousSizes, FlowbitePaginationPreviousTheme, FlowbitePaginationSizes, FlowbitePaginationTheme };
