import * as ng_primitives_state from 'ng-primitives/state';
import * as _angular_core from '@angular/core';
import { InjectionToken, Provider } from '@angular/core';
import { FlowbiteBoolean, FlowbiteColors, ColorToTheme, DeepPartial } from 'flowbite-angular';
import * as _angular_cdk_coercion from '@angular/cdk/coercion';
import { BooleanInput } from '@angular/cdk/coercion';
import * as flowbite_angular_sidebar from 'flowbite-angular/sidebar';
import * as i1 from 'flowbite-angular/button';
import { FlowbiteBaseButtonSizes, FlowbiteBaseButtonColors } from 'flowbite-angular/button';
import * as i2 from 'ng-primitives/button';
import * as i3 from 'ng-primitives/interactions';

interface FlowbiteSidebarColors extends Pick<FlowbiteColors, 'default' | 'info' | 'failure' | 'success' | 'warning' | 'primary'> {
    [key: string]: ColorToTheme;
}
interface FlowbiteSidebarTheme {
    host: FlowbiteSidebarHostTheme;
}
interface FlowbiteSidebarHostTheme {
    base: string;
    transition: string;
    open: FlowbiteBoolean;
}
declare const flowbiteSidebarTheme: FlowbiteSidebarTheme;

interface FlowbiteSidebarConfig {
    /**
     * The default theme of sidebar
     */
    baseTheme: FlowbiteSidebarTheme;
    /**
     * Whether the sidebar is open
     */
    open: boolean;
    /**
     * The default color of sidebar
     */
    color: keyof FlowbiteSidebarColors;
    /**
     * The custom theme of sidebar
     */
    customTheme: DeepPartial<FlowbiteSidebarTheme>;
}
declare const defaultFlowbiteSidebarConfig: FlowbiteSidebarConfig;
declare const FlowbiteSidebarConfigToken: InjectionToken<FlowbiteSidebarConfig>;
/**
 * Provide the default Sidebar configuration
 * @param config The Sidebar configuration
 * @returns The provider
 */
declare const provideFlowbiteSidebarConfig: (config: Partial<FlowbiteSidebarConfig>) => Provider[];
/**
 * Inject the Sidebar configuration
 * @see {@link defaultFlowbiteSidebarConfig}
 * @returns The configuration
 */
declare const injectFlowbiteSidebarConfig: () => FlowbiteSidebarConfig;

declare class Sidebar {
    protected readonly config: FlowbiteSidebarConfig;
    /**
     * @see {@link injectFlowbiteSidebarConfig}
     */
    readonly open: _angular_core.InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * @see {@link injectFlowbiteSidebarConfig}
     */
    readonly color: _angular_core.InputSignal<keyof FlowbiteSidebarColors>;
    /**
     * @see {@link injectFlowbiteSidebarConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            open?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<Sidebar>;
    /**
     * @internal
     */
    onClick(): void;
    /**
     * @internal
     */
    toggle(newState?: boolean): void;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<Sidebar, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<Sidebar, "    aside[flowbiteSidebar]  ", ["flowbiteSidebar"], { "open": { "alias": "open"; "required": false; "isSignal": true; }; "color": { "alias": "color"; "required": false; "isSignal": true; }; "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, never>;
}

declare const FlowbiteSidebarStateToken: _angular_core.InjectionToken<Sidebar>;
declare const provideFlowbiteSidebarState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteSidebarState: <U = {
    readonly config: flowbite_angular_sidebar.FlowbiteSidebarConfig;
    readonly open: _angular_core.InputSignalWithTransform<boolean, _angular_cdk_coercion.BooleanInput>;
    readonly color: _angular_core.InputSignal<keyof flowbite_angular_sidebar.FlowbiteSidebarColors>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            open?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<Sidebar>;
    onClick: () => void;
    toggle: (newState?: boolean) => void;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteSidebarState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

interface FlowbiteSidebarContentTheme {
    host: FlowbiteSidebarContentHostTheme;
    container: FlowbiteSidebarContentContainerTheme;
}
interface FlowbiteSidebarContentHostTheme {
    base: string;
    transition: string;
    open: FlowbiteBoolean;
    color: FlowbiteSidebarColors;
}
interface FlowbiteSidebarContentContainerTheme {
    base: string;
}
declare const flowbiteSidebarContentTheme: FlowbiteSidebarContentTheme;

interface FlowbiteSidebarContentConfig {
    /**
     * The default theme of sidebar-content
     */
    baseTheme: FlowbiteSidebarContentTheme;
    /**
     * The custom theme of sidebar-content
     */
    customTheme: DeepPartial<FlowbiteSidebarContentTheme>;
}
declare const defaultFlowbiteSidebarContentConfig: FlowbiteSidebarContentConfig;
declare const FlowbiteSidebarContentConfigToken: InjectionToken<FlowbiteSidebarContentConfig>;
/**
 * Provide the default SidebarContent configuration
 * @param config The SidebarContent configuration
 * @returns The provider
 */
declare const provideFlowbiteSidebarContentConfig: (config: Partial<FlowbiteSidebarContentConfig>) => Provider[];
/**
 * Inject the SidebarContent configuration
 * @see {@link defaultFlowbiteSidebarContentConfig}
 * @returns The configuration
 */
declare const injectFlowbiteSidebarContentConfig: () => FlowbiteSidebarContentConfig;

declare class SidebarContent {
    readonly config: FlowbiteSidebarContentConfig;
    readonly sidebarState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: flowbite_angular_sidebar.FlowbiteSidebarConfig;
        readonly open: _angular_core.InputSignalWithTransform<boolean, _angular_cdk_coercion.BooleanInput>;
        readonly color: _angular_core.InputSignal<keyof flowbite_angular_sidebar.FlowbiteSidebarColors>;
        readonly customTheme: _angular_core.InputSignal<{
            host?: {
                base?: string | undefined;
                transition?: string | undefined;
                open?: {
                    off?: string | undefined;
                    on?: string | undefined;
                } | undefined;
            } | undefined;
        }>;
        readonly theme: _angular_core.Signal<{
            host: {
                root: string;
            };
        }>;
        readonly state: ng_primitives_state.CreatedState<flowbite_angular_sidebar.Sidebar>;
        onClick: () => void;
        toggle: (newState?: boolean) => void;
    }>>;
    /**
     * @see {@link injectFlowbiteSidebarContentConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            open?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
        container?: {
            base?: string | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
        container: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<SidebarContent>;
    /**
     * @internal
     */
    onClick($event: MouseEvent): void;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<SidebarContent, never>;
    static ɵcmp: _angular_core.ɵɵComponentDeclaration<SidebarContent, "    div[flowbiteSidebarContent]  ", ["flowbiteSidebarContent"], { "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, ["*"], true, never>;
}

declare const FlowbiteSidebarContentStateToken: _angular_core.InjectionToken<SidebarContent>;
declare const provideFlowbiteSidebarContentState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteSidebarContentState: <U = {
    readonly config: flowbite_angular_sidebar.FlowbiteSidebarContentConfig;
    readonly sidebarState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: /*elided*/ any;
        readonly open: /*elided*/ any;
        readonly color: /*elided*/ any;
        readonly customTheme: /*elided*/ any;
        readonly theme: /*elided*/ any;
        readonly state: /*elided*/ any;
        onClick: /*elided*/ any;
        toggle: /*elided*/ any;
    }>>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            open?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
        container?: {
            base?: string | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
        container: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<SidebarContent>;
    onClick: ($event: MouseEvent) => void;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteSidebarContentState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

interface FlowbiteSidebarToggleTheme {
    host: FlowbiteSidebarToggleHostTheme;
}
interface FlowbiteSidebarToggleHostTheme {
    base: string;
    transition: string;
    focus: string;
    disabled: string;
    size: FlowbiteBaseButtonSizes;
    pill: FlowbiteBoolean;
    color: FlowbiteBaseButtonColors;
    colorOutline: FlowbiteBaseButtonColors;
}
declare const flowbiteSidebarToggleTheme: FlowbiteSidebarToggleTheme;

interface FlowbiteSidebarToggleConfig {
    /**
     * The default theme of sidebar-toggle
     */
    baseTheme: FlowbiteSidebarToggleTheme;
    /**
     * The custom theme of sidebar-toggle
     */
    customTheme: DeepPartial<FlowbiteSidebarToggleTheme>;
}
declare const defaultFlowbiteSidebarToggleConfig: FlowbiteSidebarToggleConfig;
declare const FlowbiteSidebarToggleConfigToken: InjectionToken<FlowbiteSidebarToggleConfig>;
/**
 * Provide the default SidebarToggle configuration
 * @param config The SidebarToggle configuration
 * @returns The provider
 */
declare const provideFlowbiteSidebarToggleConfig: (config: Partial<FlowbiteSidebarToggleConfig>) => Provider[];
/**
 * Inject the SidebarToggle configuration
 * @see {@link defaultFlowbiteSidebarToggleConfig}
 * @returns The configuration
 */
declare const injectFlowbiteSidebarToggleConfig: () => FlowbiteSidebarToggleConfig;

declare class SidebarToggle {
    protected readonly config: FlowbiteSidebarToggleConfig;
    protected readonly sidebarState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: flowbite_angular_sidebar.FlowbiteSidebarConfig;
        readonly open: _angular_core.InputSignalWithTransform<boolean, _angular_cdk_coercion.BooleanInput>;
        readonly color: _angular_core.InputSignal<keyof flowbite_angular_sidebar.FlowbiteSidebarColors>;
        readonly customTheme: _angular_core.InputSignal<{
            host?: {
                base?: string | undefined;
                transition?: string | undefined;
                open?: {
                    off?: string | undefined;
                    on?: string | undefined;
                } | undefined;
            } | undefined;
        }>;
        readonly theme: _angular_core.Signal<{
            host: {
                root: string;
            };
        }>;
        readonly state: ng_primitives_state.CreatedState<flowbite_angular_sidebar.Sidebar>;
        onClick: () => void;
        toggle: (newState?: boolean) => void;
    }>>;
    /**
     * @see {@link injectFlowbiteSidebarToggleConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            focus?: string | undefined;
            disabled?: string | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
                xl?: string | undefined;
            } | undefined;
            pill?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
            colorOutline?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<SidebarToggle>;
    /**
     * @internal
     */
    onClick(): void;
    /**
     * @internal
     */
    toggleSidebar(): void;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<SidebarToggle, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<SidebarToggle, "    button[flowbiteSidebarToggle]  ", ["flowbiteSidebarToggle"], { "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, [{ directive: typeof i1.BaseButton; inputs: {}; outputs: {}; }]>;
}

declare const FlowbiteSidebarToggleStateToken: _angular_core.InjectionToken<SidebarToggle>;
declare const provideFlowbiteSidebarToggleState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteSidebarToggleState: <U = {
    readonly config: flowbite_angular_sidebar.FlowbiteSidebarToggleConfig;
    readonly sidebarState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: /*elided*/ any;
        readonly open: /*elided*/ any;
        readonly color: /*elided*/ any;
        readonly customTheme: /*elided*/ any;
        readonly theme: /*elided*/ any;
        readonly state: /*elided*/ any;
        onClick: /*elided*/ any;
        toggle: /*elided*/ any;
    }>>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            focus?: string | undefined;
            disabled?: string | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
                xl?: string | undefined;
            } | undefined;
            pill?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
            colorOutline?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<SidebarToggle>;
    onClick: () => void;
    toggleSidebar: () => void;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteSidebarToggleState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

interface FlowbiteSidebarItemTheme {
    host: FlowbiteSidebarItemHostTheme;
}
interface FlowbiteSidebarItemHostTheme {
    base: string;
    transition: string;
    focus: string;
    disabled: string;
    size: FlowbiteBaseButtonSizes;
    pill: FlowbiteBoolean;
    color: FlowbiteBaseButtonColors;
    colorOutline: FlowbiteBaseButtonColors;
}
declare const flowbiteSidebarItemTheme: FlowbiteSidebarItemTheme;

interface FlowbiteSidebarItemConfig {
    /**
     * The default theme of sidebar-item
     */
    baseTheme: FlowbiteSidebarItemTheme;
    /**
     * The custom theme of sidebar-item
     */
    customTheme: DeepPartial<FlowbiteSidebarItemTheme>;
}
declare const defaultFlowbiteSidebarItemConfig: FlowbiteSidebarItemConfig;
declare const FlowbiteSidebarItemConfigToken: InjectionToken<FlowbiteSidebarItemConfig>;
/**
 * Provide the default SidebarItem configuration
 * @param config The SidebarItem configuration
 * @returns The provider
 */
declare const provideFlowbiteSidebarItemConfig: (config: Partial<FlowbiteSidebarItemConfig>) => Provider[];
/**
 * Inject the SidebarItem configuration
 * @see {@link defaultFlowbiteSidebarItemConfig}
 * @returns The configuration
 */
declare const injectFlowbiteSidebarItemConfig: () => FlowbiteSidebarItemConfig;

declare class SidebarItem {
    readonly config: FlowbiteSidebarItemConfig;
    readonly sidebarState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: flowbite_angular_sidebar.FlowbiteSidebarConfig;
        readonly open: _angular_core.InputSignalWithTransform<boolean, _angular_cdk_coercion.BooleanInput>;
        readonly color: _angular_core.InputSignal<keyof flowbite_angular_sidebar.FlowbiteSidebarColors>;
        readonly customTheme: _angular_core.InputSignal<{
            host?: {
                base?: string | undefined;
                transition?: string | undefined;
                open?: {
                    off?: string | undefined;
                    on?: string | undefined;
                } | undefined;
            } | undefined;
        }>;
        readonly theme: _angular_core.Signal<{
            host: {
                root: string;
            };
        }>;
        readonly state: ng_primitives_state.CreatedState<flowbite_angular_sidebar.Sidebar>;
        onClick: () => void;
        toggle: (newState?: boolean) => void;
    }>>;
    /**
     * @see {@link injectFlowbiteSidebarItemConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            focus?: string | undefined;
            disabled?: string | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
                xl?: string | undefined;
            } | undefined;
            pill?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
            colorOutline?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<SidebarItem>;
    /**
     * @internal
     */
    onClick(): void;
    /**
     * @internal
     */
    toggleSidebar(): void;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<SidebarItem, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<SidebarItem, "    a[flowbiteSidebarItem],    button[flowbiteSidebarItem]  ", ["flowbiteSidebarItem"], { "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, [{ directive: typeof i1.BaseButton; inputs: {}; outputs: {}; }, { directive: typeof i2.NgpButton; inputs: { "disabled": "disabled"; }; outputs: {}; }, { directive: typeof i3.NgpFocus; inputs: { "ngpFocusDisabled": "focusDisabled"; }; outputs: { "ngpFocus": "ngpFocus"; }; }]>;
}

declare const FlowbiteSidebarItemStateToken: _angular_core.InjectionToken<SidebarItem>;
declare const provideFlowbiteSidebarItemState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteSidebarItemState: <U = {
    readonly config: flowbite_angular_sidebar.FlowbiteSidebarItemConfig;
    readonly sidebarState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: /*elided*/ any;
        readonly open: /*elided*/ any;
        readonly color: /*elided*/ any;
        readonly customTheme: /*elided*/ any;
        readonly theme: /*elided*/ any;
        readonly state: /*elided*/ any;
        onClick: /*elided*/ any;
        toggle: /*elided*/ any;
    }>>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            focus?: string | undefined;
            disabled?: string | undefined;
            size?: {
                [x: string]: string | undefined;
                xs?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
                xl?: string | undefined;
            } | undefined;
            pill?: {
                off?: string | undefined;
                on?: string | undefined;
            } | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
            colorOutline?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<SidebarItem>;
    onClick: () => void;
    toggleSidebar: () => void;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteSidebarItemState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

export { FlowbiteSidebarConfigToken, FlowbiteSidebarContentConfigToken, FlowbiteSidebarContentStateToken, FlowbiteSidebarItemConfigToken, FlowbiteSidebarItemStateToken, FlowbiteSidebarStateToken, FlowbiteSidebarToggleConfigToken, FlowbiteSidebarToggleStateToken, Sidebar, SidebarContent, SidebarItem, SidebarToggle, defaultFlowbiteSidebarConfig, defaultFlowbiteSidebarContentConfig, defaultFlowbiteSidebarItemConfig, defaultFlowbiteSidebarToggleConfig, flowbiteSidebarContentState, flowbiteSidebarContentTheme, flowbiteSidebarItemState, flowbiteSidebarItemTheme, flowbiteSidebarState, flowbiteSidebarTheme, flowbiteSidebarToggleState, flowbiteSidebarToggleTheme, injectFlowbiteSidebarConfig, injectFlowbiteSidebarContentConfig, injectFlowbiteSidebarContentState, injectFlowbiteSidebarItemConfig, injectFlowbiteSidebarItemState, injectFlowbiteSidebarState, injectFlowbiteSidebarToggleConfig, injectFlowbiteSidebarToggleState, provideFlowbiteSidebarConfig, provideFlowbiteSidebarContentConfig, provideFlowbiteSidebarContentState, provideFlowbiteSidebarItemConfig, provideFlowbiteSidebarItemState, provideFlowbiteSidebarState, provideFlowbiteSidebarToggleConfig, provideFlowbiteSidebarToggleState };
export type { FlowbiteSidebarColors, FlowbiteSidebarConfig, FlowbiteSidebarContentConfig, FlowbiteSidebarContentContainerTheme, FlowbiteSidebarContentHostTheme, FlowbiteSidebarContentTheme, FlowbiteSidebarHostTheme, FlowbiteSidebarItemConfig, FlowbiteSidebarItemHostTheme, FlowbiteSidebarItemTheme, FlowbiteSidebarTheme, FlowbiteSidebarToggleConfig, FlowbiteSidebarToggleHostTheme, FlowbiteSidebarToggleTheme };
