import * as ng_primitives_state from 'ng-primitives/state';
import * as _angular_core from '@angular/core';
import { InjectionToken, Provider } from '@angular/core';
import * as flowbite_angular_tab from 'flowbite-angular/tab';
import { FlowbiteSizes, FlowbiteColors, ColorToTheme, DeepPartial } from 'flowbite-angular';
import * as i1 from 'ng-primitives/tabs';
import * as i2 from 'ng-primitives/interactions';
import * as i3 from 'flowbite-angular/button';

interface FlowbiteTabSizes extends Pick<FlowbiteSizes, 'sm' | 'md' | 'lg'> {
    [key: string]: string;
    full: string;
}
interface FlowbiteTabColors extends Pick<FlowbiteColors, 'default' | 'info' | 'failure' | 'success' | 'warning' | 'primary'> {
    [key: string]: ColorToTheme;
}
interface FlowbiteTabTheme {
    host: FlowbiteTabHostTheme;
}
interface FlowbiteTabHostTheme {
    base: string;
    transition: string;
    size: FlowbiteTabSizes;
    color: FlowbiteTabColors;
}
declare const flowbiteTabTheme: FlowbiteTabTheme;

interface FlowbiteTabConfig {
    /**
     * The default theme of Tab
     */
    baseTheme: FlowbiteTabTheme;
    /**
     * The default size of Tab
     */
    size: keyof FlowbiteTabSizes;
    /**
     * The default color of Tab
     */
    color: keyof FlowbiteTabColors;
    /**
     * The custom theme of Tab
     */
    customTheme: DeepPartial<FlowbiteTabTheme>;
}
declare const defaultFlowbiteTabConfig: FlowbiteTabConfig;
declare const FlowbiteTabConfigToken: InjectionToken<FlowbiteTabConfig>;
/**
 * Provide the default Tab configuration
 * @param config The Tab configuration
 * @returns The provider
 */
declare const provideFlowbiteTabConfig: (config: Partial<FlowbiteTabConfig>) => Provider[];
/**
 * Inject the Tab configuration
 * @see {@link defaultFlowbiteTabConfig}
 * @returns The configuration
 */
declare const injectFlowbiteTabConfig: () => FlowbiteTabConfig;

declare class Tab {
    readonly config: FlowbiteTabConfig;
    /**
     * @see {@link injectFlowbiteTabConfig}
     */
    readonly size: _angular_core.InputSignal<keyof flowbite_angular_tab.FlowbiteTabSizes>;
    /**
     * @see {@link injectFlowbiteTabConfig}
     */
    readonly color: _angular_core.InputSignal<keyof flowbite_angular_tab.FlowbiteTabColors>;
    /**
     * @see {@link injectFlowbiteTabConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            size?: {
                [x: string]: string | undefined;
                full?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
            } | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<Tab>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<Tab, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<Tab, "    [flowbiteTab]  ", ["flowbiteTab"], { "size": { "alias": "size"; "required": false; "isSignal": true; }; "color": { "alias": "color"; "required": false; "isSignal": true; }; "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, [{ directive: typeof i1.NgpTabset; inputs: { "id": "id"; "ngpTabsetValue": "value"; "ngpTabsetActivateOnFocus": "activateOnFocus"; }; outputs: { "ngpTabsetValueChange": "valueChange"; }; }]>;
}

declare const FlowbiteTabStateToken: _angular_core.InjectionToken<Tab>;
declare const provideFlowbiteTabState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteTabState: <U = {
    readonly config: flowbite_angular_tab.FlowbiteTabConfig;
    readonly size: _angular_core.InputSignal<keyof flowbite_angular_tab.FlowbiteTabSizes>;
    readonly color: _angular_core.InputSignal<keyof flowbite_angular_tab.FlowbiteTabColors>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            size?: {
                [x: string]: string | undefined;
                full?: string | undefined;
                sm?: string | undefined;
                md?: string | undefined;
                lg?: string | undefined;
            } | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<Tab>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteTabState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

interface FlowbiteTabListTheme {
    host: FlowbiteTabListHostTheme;
}
interface FlowbiteTabListHostTheme {
    base: string;
    transition: string;
    color: FlowbiteTabColors;
}
declare const flowbiteTabListTheme: FlowbiteTabListTheme;

interface FlowbiteTabListConfig {
    /**
     * The default theme of TabList
     */
    baseTheme: FlowbiteTabListTheme;
    /**
     * The custom theme of TabList
     */
    customTheme: DeepPartial<FlowbiteTabListTheme>;
}
declare const defaultFlowbiteTabListConfig: FlowbiteTabListConfig;
declare const FlowbiteTabListConfigToken: InjectionToken<FlowbiteTabListConfig>;
/**
 * Provide the default TabList configuration
 * @param config The TabList configuration
 * @returns The provider
 */
declare const provideFlowbiteTabListConfig: (config: Partial<FlowbiteTabListConfig>) => Provider[];
/**
 * Inject the TabList configuration
 * @see {@link defaultFlowbiteTabListConfig}
 * @returns The configuration
 */
declare const injectFlowbiteTabListConfig: () => FlowbiteTabListConfig;

declare class TabList {
    readonly config: FlowbiteTabListConfig;
    readonly tabState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: flowbite_angular_tab.FlowbiteTabConfig;
        readonly size: _angular_core.InputSignal<keyof flowbite_angular_tab.FlowbiteTabSizes>;
        readonly color: _angular_core.InputSignal<keyof flowbite_angular_tab.FlowbiteTabColors>;
        readonly customTheme: _angular_core.InputSignal<{
            host?: {
                base?: string | undefined;
                transition?: string | undefined;
                size?: {
                    [x: string]: string | undefined;
                    full?: string | undefined;
                    sm?: string | undefined;
                    md?: string | undefined;
                    lg?: string | undefined;
                } | undefined;
                color?: {
                    [x: string]: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    default?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    info?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    failure?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    success?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    warning?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    primary?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                } | undefined;
            } | undefined;
        }>;
        readonly theme: _angular_core.Signal<{
            host: {
                root: string;
            };
        }>;
        readonly state: ng_primitives_state.CreatedState<flowbite_angular_tab.Tab>;
    }>>;
    /**
     * @see {@link injectFlowbiteTabListConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<TabList>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<TabList, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<TabList, "    ul[flowbiteTabList]  ", ["flowbiteTabList"], { "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, [{ directive: typeof i1.NgpTabList; inputs: {}; outputs: {}; }]>;
}

declare const FlowbiteTabListStateToken: _angular_core.InjectionToken<TabList>;
declare const provideFlowbiteTabListState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteTabListState: <U = {
    readonly config: flowbite_angular_tab.FlowbiteTabListConfig;
    readonly tabState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: /*elided*/ any;
        readonly size: /*elided*/ any;
        readonly color: /*elided*/ any;
        readonly customTheme: /*elided*/ any;
        readonly theme: /*elided*/ any;
        readonly state: /*elided*/ any;
    }>>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<TabList>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteTabListState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

interface FlowbiteTabButtonTheme {
    host: FlowbiteTabButtonHostTheme;
}
interface FlowbiteTabButtonHostTheme {
    base: string;
    transition: string;
    color: FlowbiteTabColors;
}
declare const flowbiteTabButtonTheme: FlowbiteTabButtonTheme;

interface FlowbiteTabButtonConfig {
    /**
     * The default theme of TabButton
     */
    baseTheme: FlowbiteTabButtonTheme;
    /**
     * The custom theme of TabButton
     */
    customTheme: DeepPartial<FlowbiteTabButtonTheme>;
}
declare const defaultFlowbiteTabButtonConfig: FlowbiteTabButtonConfig;
declare const FlowbiteTabButtonConfigToken: InjectionToken<FlowbiteTabButtonConfig>;
/**
 * Provide the default TabButton configuration
 * @param config The TabButton configuration
 * @returns The provider
 */
declare const provideFlowbiteTabButtonConfig: (config: Partial<FlowbiteTabButtonConfig>) => Provider[];
/**
 * Inject the TabButton configuration
 * @see {@link defaultFlowbiteTabButtonConfig}
 * @returns The configuration
 */
declare const injectFlowbiteTabButtonConfig: () => FlowbiteTabButtonConfig;

declare class TabButton {
    readonly config: FlowbiteTabButtonConfig;
    readonly tabState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: flowbite_angular_tab.FlowbiteTabConfig;
        readonly size: _angular_core.InputSignal<keyof flowbite_angular_tab.FlowbiteTabSizes>;
        readonly color: _angular_core.InputSignal<keyof flowbite_angular_tab.FlowbiteTabColors>;
        readonly customTheme: _angular_core.InputSignal<{
            host?: {
                base?: string | undefined;
                transition?: string | undefined;
                size?: {
                    [x: string]: string | undefined;
                    full?: string | undefined;
                    sm?: string | undefined;
                    md?: string | undefined;
                    lg?: string | undefined;
                } | undefined;
                color?: {
                    [x: string]: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    default?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    info?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    failure?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    success?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    warning?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    primary?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                } | undefined;
            } | undefined;
        }>;
        readonly theme: _angular_core.Signal<{
            host: {
                root: string;
            };
        }>;
        readonly state: ng_primitives_state.CreatedState<flowbite_angular_tab.Tab>;
    }>>;
    /**
     * @see {@link injectFlowbiteTabButtonConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<TabButton>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<TabButton, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<TabButton, "    li[flowbiteTabButton]  ", ["flowbiteTabButton"], { "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, [{ directive: typeof i1.NgpTabButton; inputs: { "id": "id"; "ngpTabButtonValue": "value"; "ngpTabButtonDisabled": "disabled"; }; outputs: {}; }, { directive: typeof i2.NgpFocus; inputs: {}; outputs: {}; }, { directive: typeof i3.BaseButton; inputs: {}; outputs: {}; }]>;
}

declare const FlowbiteTabButtonStateToken: _angular_core.InjectionToken<TabButton>;
declare const provideFlowbiteTabButtonState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteTabButtonState: <U = {
    readonly config: flowbite_angular_tab.FlowbiteTabButtonConfig;
    readonly tabState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: /*elided*/ any;
        readonly size: /*elided*/ any;
        readonly color: /*elided*/ any;
        readonly customTheme: /*elided*/ any;
        readonly theme: /*elided*/ any;
        readonly state: /*elided*/ any;
    }>>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<TabButton>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteTabButtonState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

interface FlowbiteTabContentTheme {
    host: FlowbiteTabContentHostTheme;
}
interface FlowbiteTabContentHostTheme {
    base: string;
    transition: string;
    color: FlowbiteTabColors;
}
declare const flowbiteTabContentTheme: FlowbiteTabContentTheme;

interface FlowbiteTabContentConfig {
    /**
     * The default theme of TabContent
     */
    baseTheme: FlowbiteTabContentTheme;
    /**
     * The custom theme of TabContent
     */
    customTheme: DeepPartial<FlowbiteTabContentTheme>;
}
declare const defaultFlowbiteTabContentConfig: FlowbiteTabContentConfig;
declare const FlowbiteTabContentConfigToken: InjectionToken<FlowbiteTabContentConfig>;
/**
 * Provide the default TabContent configuration
 * @param config The TabContent configuration
 * @returns The provider
 */
declare const provideFlowbiteTabContentConfig: (config: Partial<FlowbiteTabContentConfig>) => Provider[];
/**
 * Inject the TabContent configuration
 * @see {@link defaultFlowbiteTabContentConfig}
 * @returns The configuration
 */
declare const injectFlowbiteTabContentConfig: () => FlowbiteTabContentConfig;

declare class TabContent {
    readonly config: FlowbiteTabContentConfig;
    readonly tabState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: flowbite_angular_tab.FlowbiteTabConfig;
        readonly size: _angular_core.InputSignal<keyof flowbite_angular_tab.FlowbiteTabSizes>;
        readonly color: _angular_core.InputSignal<keyof flowbite_angular_tab.FlowbiteTabColors>;
        readonly customTheme: _angular_core.InputSignal<{
            host?: {
                base?: string | undefined;
                transition?: string | undefined;
                size?: {
                    [x: string]: string | undefined;
                    full?: string | undefined;
                    sm?: string | undefined;
                    md?: string | undefined;
                    lg?: string | undefined;
                } | undefined;
                color?: {
                    [x: string]: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    default?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    info?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    failure?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    success?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    warning?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                    primary?: {
                        light?: string | undefined;
                        dark?: string | undefined;
                    } | undefined;
                } | undefined;
            } | undefined;
        }>;
        readonly theme: _angular_core.Signal<{
            host: {
                root: string;
            };
        }>;
        readonly state: ng_primitives_state.CreatedState<flowbite_angular_tab.Tab>;
    }>>;
    /**
     * @see {@link injectFlowbiteTabContentConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<TabContent>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<TabContent, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<TabContent, "    [flowbiteTabContent]  ", ["flowbiteTabContent"], { "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, [{ directive: typeof i1.NgpTabPanel; inputs: { "id": "id"; "ngpTabPanelValue": "value"; }; outputs: {}; }]>;
}

declare const FlowbiteTabContentStateToken: _angular_core.InjectionToken<TabContent>;
declare const provideFlowbiteTabContentState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteTabContentState: <U = {
    readonly config: flowbite_angular_tab.FlowbiteTabContentConfig;
    readonly tabState: _angular_core.Signal<ng_primitives_state.State<{
        readonly config: /*elided*/ any;
        readonly size: /*elided*/ any;
        readonly color: /*elided*/ any;
        readonly customTheme: /*elided*/ any;
        readonly theme: /*elided*/ any;
        readonly state: /*elided*/ any;
    }>>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<TabContent>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteTabContentState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

declare const greeting = "Hello World!";

export { FlowbiteTabButtonConfigToken, FlowbiteTabButtonStateToken, FlowbiteTabConfigToken, FlowbiteTabContentConfigToken, FlowbiteTabContentStateToken, FlowbiteTabListConfigToken, FlowbiteTabListStateToken, FlowbiteTabStateToken, Tab, TabButton, TabContent, TabList, defaultFlowbiteTabButtonConfig, defaultFlowbiteTabConfig, defaultFlowbiteTabContentConfig, defaultFlowbiteTabListConfig, flowbiteTabButtonState, flowbiteTabButtonTheme, flowbiteTabContentState, flowbiteTabContentTheme, flowbiteTabListState, flowbiteTabListTheme, flowbiteTabState, flowbiteTabTheme, greeting, injectFlowbiteTabButtonConfig, injectFlowbiteTabButtonState, injectFlowbiteTabConfig, injectFlowbiteTabContentConfig, injectFlowbiteTabContentState, injectFlowbiteTabListConfig, injectFlowbiteTabListState, injectFlowbiteTabState, provideFlowbiteTabButtonConfig, provideFlowbiteTabButtonState, provideFlowbiteTabConfig, provideFlowbiteTabContentConfig, provideFlowbiteTabContentState, provideFlowbiteTabListConfig, provideFlowbiteTabListState, provideFlowbiteTabState };
export type { FlowbiteTabButtonConfig, FlowbiteTabButtonHostTheme, FlowbiteTabButtonTheme, FlowbiteTabColors, FlowbiteTabConfig, FlowbiteTabContentConfig, FlowbiteTabContentHostTheme, FlowbiteTabContentTheme, FlowbiteTabHostTheme, FlowbiteTabListConfig, FlowbiteTabListHostTheme, FlowbiteTabListTheme, FlowbiteTabSizes, FlowbiteTabTheme };
