import * as ng_primitives_state from 'ng-primitives/state';
import * as _angular_core from '@angular/core';
import { InjectionToken, Provider } from '@angular/core';
import { FlowbiteColors, ColorToTheme, DeepPartial } from 'flowbite-angular';
import * as flowbite_angular_tooltip from 'flowbite-angular/tooltip';

interface FlowbiteTooltipColors extends Pick<FlowbiteColors, 'default' | 'info' | 'failure' | 'success' | 'warning' | 'primary'> {
    [key: string]: ColorToTheme;
}
interface FlowbiteTooltipTheme {
    host: FlowbiteTooltipHostTheme;
}
interface FlowbiteTooltipHostTheme {
    base: string;
    transition: string;
    color: FlowbiteTooltipColors;
}
declare const flowbiteTooltipTheme: FlowbiteTooltipTheme;

interface FlowbiteTooltipConfig {
    /**
     * The default theme of tooltip
     */
    baseTheme: FlowbiteTooltipTheme;
    /**
     * The default color of tooltip
     */
    color: keyof FlowbiteTooltipColors;
    /**
     * The custom theme of tooltip
     */
    customTheme: DeepPartial<FlowbiteTooltipTheme>;
}
declare const defaultFlowbiteTooltipConfig: FlowbiteTooltipConfig;
declare const FlowbiteTooltipConfigToken: InjectionToken<FlowbiteTooltipConfig>;
/**
 * Provide the default Tooltip configuration
 * @param config The Tooltip configuration
 * @returns The provider
 */
declare const provideFlowbiteTooltipConfig: (config: Partial<FlowbiteTooltipConfig>) => Provider[];
/**
 * Inject the Tooltip configuration
 * @see {@link defaultFlowbiteTooltipConfig}
 * @returns The configuration
 */
declare const injectFlowbiteTooltipConfig: () => FlowbiteTooltipConfig;

declare class Tooltip {
    protected readonly config: FlowbiteTooltipConfig;
    /**
     * @see {@link injectFlowbiteTooltipConfig}
     */
    readonly color: _angular_core.InputSignal<keyof FlowbiteTooltipColors>;
    /**
     * @see {@link injectFlowbiteTooltipConfig}
     */
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    /**
     * @internal
     */
    readonly state: ng_primitives_state.CreatedState<Tooltip>;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<Tooltip, never>;
    static ɵdir: _angular_core.ɵɵDirectiveDeclaration<Tooltip, "    [flowbiteTooltip]  ", ["flowbiteTooltip"], { "color": { "alias": "color"; "required": false; "isSignal": true; }; "customTheme": { "alias": "customTheme"; "required": false; "isSignal": true; }; }, {}, never, never, true, never>;
}

declare const FlowbiteTooltipStateToken: _angular_core.InjectionToken<Tooltip>;
declare const provideFlowbiteTooltipState: (options?: ng_primitives_state.CreateStateProviderOptions) => _angular_core.FactoryProvider;
declare const injectFlowbiteTooltipState: <U = {
    readonly config: flowbite_angular_tooltip.FlowbiteTooltipConfig;
    readonly color: _angular_core.InputSignal<keyof flowbite_angular_tooltip.FlowbiteTooltipColors>;
    readonly customTheme: _angular_core.InputSignal<{
        host?: {
            base?: string | undefined;
            transition?: string | undefined;
            color?: {
                [x: string]: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                default?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                info?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                failure?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                success?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                warning?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
                primary?: {
                    light?: string | undefined;
                    dark?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
    }>;
    readonly theme: _angular_core.Signal<{
        host: {
            root: string;
        };
    }>;
    readonly state: ng_primitives_state.CreatedState<Tooltip>;
}>(injectOptions?: _angular_core.InjectOptions) => _angular_core.Signal<ng_primitives_state.State<U>>;
declare const flowbiteTooltipState: <U>(state: U) => ng_primitives_state.CreatedState<U>;

export { FlowbiteTooltipConfigToken, FlowbiteTooltipStateToken, Tooltip, defaultFlowbiteTooltipConfig, flowbiteTooltipState, flowbiteTooltipTheme, injectFlowbiteTooltipConfig, injectFlowbiteTooltipState, provideFlowbiteTooltipConfig, provideFlowbiteTooltipState };
export type { FlowbiteTooltipColors, FlowbiteTooltipConfig, FlowbiteTooltipHostTheme, FlowbiteTooltipTheme };
